(* Copyright (c) <2003-2020> <Julio Jerez, Newton Game Dynamics>
 *
 * This software is provided 'as-is', without any express or implied
 * warranty. In no event will the authors be held liable for any damages
 * arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any purpose,
 * including commercial applications, and to alter it and redistribute it
 * freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must not
 * claim that you wrote the original software. If you use this software
 * in a product, an acknowledgment in the product documentation would be
 * appreciated but is not required.
 *
 * 2. Altered source versions must be plainly marked as such, and must not be
 * misrepresented as being the original software.
 *
 * 3. This notice may not be removed or altered from any source distribution.
 *)

{ ********************************************************************** }
{ Automated Newton Pascal Header translation                             }
{ Copyright 2005-2020 Jernej L.                                          }
{ Type names are based on original work by S.Spasov(Sury)                }
{ ********************************************************************** }

// Define double to use newton in double precision

{$UNDEF double}
{.$i compiler.inc}// uncomment if you use custom compiler defines.

Unit newton;

{$MODE objfpc}{$H+}

Interface

Const
{$IFDEF Windows}
  newtondll = 'Newton.dll';
{$ELSE}
  newtondll = 'libNewton.so';
{$ENDIF}

Type

{$IFNDEF double}
  float = Single;
  dfloat = Single;
{$ELSE}
  float = Double;
  dfloat = Double;
{$ENDIF}
  Pfloat = ^float;
  Pdfloat = ^dfloat;

  Pinteger = ^integer;
  Psmallint = ^smallint;
  PPointer = ^Pointer;

  { Newton objects }
  PNewtonMesh = ^Pointer;
  PNewtonBody = ^Pointer;
  PNewtonWorld = ^Pointer;
  PNewtonJoint = ^Pointer;
  PNewtonMaterial = ^Pointer;
  PNewtonCollision = ^Pointer;
  PNewtonSceneProxy = ^Pointer;
  PNewtonFracturedCompoundMeshPart = ^Pointer;
  PNewtonDeformableMeshSegment = ^Pointer;
  PNewtonAcyclicArticulation = ^Pointer;
  PNewtonInverseDynamics = ^Pointer;

  TNewtonFuncLinkRecord = Record
    function_name: widestring;
    function_ptr: pointer
  End;


Const
  NEWTON_MAJOR_VERSION = 3;
  NEWTON_MINOR_VERSION = 15;
  NEWTON_BROADPHASE_DEFAULT = 0;
  NEWTON_BROADPHASE_PERSINTENT = 1;
  NEWTON_DYNAMIC_BODY = 0;
  NEWTON_KINEMATIC_BODY = 1;
  NEWTON_DYNAMIC_ASYMETRIC_BODY = 2;
  SERIALIZE_ID_SPHERE = 0;
  SERIALIZE_ID_CAPSULE = 1;
  SERIALIZE_ID_CYLINDER = 2;
  SERIALIZE_ID_CHAMFERCYLINDER = 3;
  SERIALIZE_ID_BOX = 4;
  SERIALIZE_ID_CONE = 5;
  SERIALIZE_ID_CONVEXHULL = 6;
  SERIALIZE_ID_NULL = 7;
  SERIALIZE_ID_COMPOUND = 8;
  SERIALIZE_ID_TREE = 9;
  SERIALIZE_ID_HEIGHTFIELD = 10;
  SERIALIZE_ID_CLOTH_PATCH = 11;
  SERIALIZE_ID_DEFORMABLE_SOLID = 12;
  SERIALIZE_ID_USERMESH = 13;
  SERIALIZE_ID_SCENE = 14;
  SERIALIZE_ID_FRACTURED_COMPOUND = 15;


Type

  TNewtonMaterialData = Packed Record
    Case integer Of
      1: (
        m_ptr: Pointer;
        );
      2: (
        m_int: int64;
        );
      3: (
        m_float: dfloat;
        );
  End;
  PNewtonMaterialData = ^TNewtonMaterialData;

  TNewtonCollisionMaterial = Packed Record
    m_userId: int64;
    m_userData: TNewtonMaterialData;
    m_userParam: Array[0..5] Of TNewtonMaterialData;
  End;
  PNewtonCollisionMaterial = ^TNewtonCollisionMaterial;

  TNewtonBoxParam = Packed Record
    m_x: dfloat;
    m_y: dfloat;
    m_z: dfloat;
  End;
  PNewtonBoxParam = ^TNewtonBoxParam;

  TNewtonSphereParam = Packed Record
    m_radio: dfloat;
  End;
  PNewtonSphereParam = ^TNewtonSphereParam;

  TNewtonCapsuleParam = Packed Record
    m_radio0: dfloat;
    m_radio1: dfloat;
    m_height: dfloat;
  End;
  PNewtonCapsuleParam = ^TNewtonCapsuleParam;

  TNewtonCylinderParam = Packed Record
    m_radio0: dfloat;
    m_radio1: dfloat;
    m_height: dfloat;
  End;
  PNewtonCylinderParam = ^TNewtonCylinderParam;

  TNewtonConeParam = Packed Record
    m_radio: dfloat;
    m_height: dfloat;
  End;
  PNewtonConeParam = ^TNewtonConeParam;

  TNewtonChamferCylinderParam = Packed Record
    m_radio: dfloat;
    m_height: dfloat;
  End;
  PNewtonChamferCylinderParam = ^TNewtonChamferCylinderParam;

  TNewtonConvexHullParam = Packed Record
    m_vertexCount: Integer;
    m_vertexStrideInBytes: Integer;
    m_faceCount: Integer;
    m_vertex: pfloat;
  End;
  PNewtonConvexHullParam = ^TNewtonConvexHullParam;

  TNewtonCompoundCollisionParam = Packed Record
    m_chidrenCount: Integer;
  End;
  PNewtonCompoundCollisionParam = ^TNewtonCompoundCollisionParam;

  TNewtonCollisionTreeParam = Packed Record
    m_vertexCount: Integer;
    m_indexCount: Integer;
  End;
  PNewtonCollisionTreeParam = ^TNewtonCollisionTreeParam;

  TNewtonDeformableMeshParam = Packed Record
    m_vertexCount: Integer;
    m_triangleCount: Integer;
    m_vrtexStrideInBytes: Integer;
    m_indexList: Pword;
    m_vertexList: Pdfloat;
  End;
  PNewtonDeformableMeshParam = ^TNewtonDeformableMeshParam;

  TNewtonHeightFieldCollisionParam = Packed Record
    m_width: Integer;
    m_height: Integer;
    m_gridsDiagonals: Integer;
    m_elevationDataType: Integer;
    m_verticalScale: dfloat;
    m_horizonalScale_x: dfloat;
    m_horizonalScale_z: dfloat;
    m_vertialElevation: Pointer;
    m_atributes: pchar;
  End;
  PNewtonHeightFieldCollisionParam = ^TNewtonHeightFieldCollisionParam;

  TNewtonSceneCollisionParam = Packed Record
    m_childrenProxyCount: Integer;
  End;
  PNewtonSceneCollisionParam = ^TNewtonSceneCollisionParam;

  TNewtonCollisionInfoRecord = Packed Record
    m_offsetMatrix: Array[0..3, 0..3] Of single;
    m_collisionMaterial: TNewtonCollisionMaterial;
    m_collisionType: integer;
    Case integer Of
      SERIALIZE_ID_BOX:
      (shapedatabox: TNewtonBoxParam);
      SERIALIZE_ID_CONE:
      (shapedata: TNewtonConeParam);
      SERIALIZE_ID_SPHERE:
      (shapedatasphere: TNewtonSphereParam);
      SERIALIZE_ID_CAPSULE:
      (shapedatacapsule: TNewtonCapsuleParam);
      SERIALIZE_ID_CYLINDER:
      (shapedatacylinder: TNewtonCylinderParam);
      //SERIALIZE_ID_TAPEREDCAPSULE:
      //(m_taperedCapsule: TNewtonTaperedCapsuleParam);
      //SERIALIZE_ID_TAPEREDCYLINDER:
      //(m_taperedCylinder: TNewtonTaperedCylinderParam);
      SERIALIZE_ID_CHAMFERCYLINDER:
      (shapedatachamfercylinder: TNewtonChamferCylinderParam);
      SERIALIZE_ID_CONVEXHULL:
      (shapedataconvexhull: TNewtonConvexHullParam);
      SERIALIZE_ID_DEFORMABLE_SOLID:
      (m_deformableMesh: TNewtonDeformableMeshParam);
      SERIALIZE_ID_COMPOUND:
      (shapedatacompound: TNewtonCompoundCollisionParam);
      SERIALIZE_ID_TREE:
      (shapedatatree: TNewtonCollisionTreeParam);
      SERIALIZE_ID_HEIGHTFIELD:
      (shapedataheightfield: TNewtonHeightFieldCollisionParam);
      SERIALIZE_ID_SCENE:
      (shapedatascenecollision: TNewtonSceneCollisionParam);
      SERIALIZE_ID_USERMESH:
      (m_paramArray: Array[0..63] Of float);
  End;
  PNewtonCollisionInfoRecord = ^TNewtonCollisionInfoRecord;

  TNewtonJointRecord = Packed Record
    m_attachmenMatrix_0: Array[0..3, 0..3] Of dfloat;
    m_attachmenMatrix_1: Array[0..3, 0..3] Of dfloat;
    m_minLinearDof: Array[0..2] Of dfloat;
    m_maxLinearDof: Array[0..2] Of dfloat;
    m_minAngularDof: Array[0..2] Of dfloat;
    m_maxAngularDof: Array[0..2] Of dfloat;
    m_attachBody_0: pNewtonBody;
    m_attachBody_1: pNewtonBody;
    m_extraParameters: Array[0..63] Of dfloat;
    m_bodiesCollisionOn: Integer;
    m_descriptionType: Array[0..127] Of AnsiChar;
  End;
  PNewtonJointRecord = ^TNewtonJointRecord;

  TNewtonUserMeshCollisionCollideDesc = Packed Record
    m_boxP0: Array[0..3] Of dfloat;
    m_boxP1: Array[0..3] Of dfloat;
    m_boxDistanceTravel: Array[0..3] Of dfloat;
    m_threadNumber: Integer;
    m_faceCount: Integer;
    m_vertexStrideInBytes: Integer;
    m_skinThickness: dfloat;
    m_userData: Pointer;
    m_objBody: pNewtonBody;
    m_polySoupBody: pNewtonBody;
    m_objCollision: PNewtonCollision;
    m_polySoupCollision: PNewtonCollision;
    m_vertex: pfloat;
    m_faceIndexCount: Pinteger;
    m_faceVertexIndex: Pinteger;
  End;
  PNewtonUserMeshCollisionCollideDesc = ^TNewtonUserMeshCollisionCollideDesc;

  TNewtonWorldConvexCastReturnInfo = Packed Record
    m_point: Array[0..3] Of dfloat;
    m_normal: Array[0..3] Of dfloat;
    m_contactID: int64;
    m_hitBody: pNewtonBody;
    m_penetration: dfloat;
  End;
  PNewtonWorldConvexCastReturnInfo = ^TNewtonWorldConvexCastReturnInfo;

  TNewtonUserMeshCollisionRayHitDesc = Packed Record
    m_p0: Array[0..3] Of dfloat;
    m_p1: Array[0..3] Of dfloat;
    m_normalOut: Array[0..3] Of dfloat;
    m_userIdOut: int64;
    m_userData: Pointer;
  End;
  PNewtonUserMeshCollisionRayHitDesc = ^TNewtonUserMeshCollisionRayHitDesc;

  TNewtonHingeSliderUpdateDesc = Packed Record
    m_accel: dfloat;
    m_minFriction: dfloat;
    m_maxFriction: dfloat;
    m_timestep: dfloat;
  End;
  PNewtonHingeSliderUpdateDesc = ^TNewtonHingeSliderUpdateDesc;

  TNewtonUserContactPoint = Packed Record
    m_point: Array[0..3] Of dfloat;
    m_normal: Array[0..3] Of dfloat;
    m_shapeId0: int64;
    m_shapeId1: int64;
    m_penetration: dfloat;
    m_unused: Array[0..2] Of Integer;
  End;
  PNewtonUserContactPoint = ^TNewtonUserContactPoint;

  TNewtonImmediateModeConstraint = Packed Record
    m_jacobian01: Array[0..7, 0..5] Of dfloat;
    m_jacobian10: Array[0..7, 0..5] Of dfloat;
    m_minFriction: Array[0..7] Of dfloat;
    m_maxFriction: Array[0..7] Of dfloat;
    m_jointAccel: Array[0..7] Of dfloat;
    m_jointStiffness: Array[0..7] Of dfloat;
  End;
  PNewtonImmediateModeConstraint = ^TNewtonImmediateModeConstraint;

  TNewtonMeshDoubleData = Packed Record
    m_data: Pdouble;
    m_indexList: Pinteger;
    m_strideInBytes: Integer;
  End;
  PNewtonMeshDoubleData = ^TNewtonMeshDoubleData;

  TNewtonMeshFloatData = Packed Record
    m_data: pfloat;
    m_indexList: Pinteger;
    m_strideInBytes: Integer;
  End;
  PNewtonMeshFloatData = ^TNewtonMeshFloatData;

  TNewtonMeshVertexFormat = Packed Record
    m_faceCount: Integer;
    m_faceIndexCount: Pinteger;
    m_faceMaterial: Pinteger;
    m_vertex: TNewtonMeshDoubleData;
    m_normal: TNewtonMeshFloatData;
    m_binormal: TNewtonMeshFloatData;
    m_uv0: TNewtonMeshFloatData;
    m_uv1: TNewtonMeshFloatData;
    m_vertexColor: TNewtonMeshFloatData;
  End;
  PNewtonMeshVertexFormat = ^TNewtonMeshVertexFormat;

  NewtonAllocMemory = Function(sizeInBytes: Integer): Pointer; cdecl;
  PNewtonAllocMemory = ^NewtonAllocMemory;

  NewtonFreeMemory = Procedure(Const ptr: Pointer; sizeInBytes: Integer); cdecl;
  PNewtonFreeMemory = ^NewtonFreeMemory;

  NewtonWorldDestructorCallback = Procedure(Const world: PNewtonWorld); cdecl;
  PNewtonWorldDestructorCallback = ^NewtonWorldDestructorCallback;

  NewtonPostUpdateCallback = Procedure(Const world: PNewtonWorld; timestep: dfloat); cdecl;
  PNewtonPostUpdateCallback = ^NewtonPostUpdateCallback;

  NewtonCreateContactCallback = Procedure(Const newtonWorld: PNewtonWorld; Const contact: PNewtonJoint); cdecl;
  PNewtonCreateContactCallback = ^NewtonCreateContactCallback;

  NewtonDestroyContactCallback = Procedure(Const newtonWorld: PNewtonWorld; Const contact: PNewtonJoint); cdecl;
  PNewtonDestroyContactCallback = ^NewtonDestroyContactCallback;

  NewtonWorldListenerDebugCallback = Procedure(Const world: PNewtonWorld; Const listener: Pointer; Const debugContext: Pointer); cdecl;
  PNewtonWorldListenerDebugCallback = ^NewtonWorldListenerDebugCallback;

  NewtonWorldListenerBodyDestroyCallback = Procedure(Const world: PNewtonWorld; Const listenerUserData: Pointer; Const body: pNewtonBody); cdecl;
  PNewtonWorldListenerBodyDestroyCallback = ^NewtonWorldListenerBodyDestroyCallback;

  NewtonWorldUpdateListenerCallback = Procedure(Const world: PNewtonWorld; Const listenerUserData: Pointer; timestep: dfloat); cdecl;
  PNewtonWorldUpdateListenerCallback = ^NewtonWorldUpdateListenerCallback;

  NewtonWorldDestroyListenerCallback = Procedure(Const world: PNewtonWorld; Const listenerUserData: Pointer); cdecl;
  PNewtonWorldDestroyListenerCallback = ^NewtonWorldDestroyListenerCallback;

  NewtonGetTimeInMicrosencondsCallback = Function(): int64; cdecl;
  PNewtonGetTimeInMicrosencondsCallback = ^NewtonGetTimeInMicrosencondsCallback;

  NewtonSerializeCallback = Procedure(Const serializeHandle: Pointer; Const buffer: Pointer; size: Integer); cdecl;
  PNewtonSerializeCallback = ^NewtonSerializeCallback;

  NewtonDeserializeCallback = Procedure(Const serializeHandle: Pointer; Const buffer: Pointer; size: Integer); cdecl;
  PNewtonDeserializeCallback = ^NewtonDeserializeCallback;

  NewtonOnBodySerializationCallback = Procedure(Const body: pNewtonBody; Const userData: Pointer; functionparam: PNewtonSerializeCallback; Const serializeHandle: Pointer); cdecl;
  PNewtonOnBodySerializationCallback = ^NewtonOnBodySerializationCallback;

  NewtonOnBodyDeserializationCallback = Procedure(Const body: pNewtonBody; Const userData: Pointer; functionparam: PNewtonDeserializeCallback; Const serializeHandle: Pointer); cdecl;
  PNewtonOnBodyDeserializationCallback = ^NewtonOnBodyDeserializationCallback;

  NewtonOnJointSerializationCallback = Procedure(Const joint: PNewtonJoint; functionparam: PNewtonSerializeCallback; Const serializeHandle: Pointer); cdecl;
  PNewtonOnJointSerializationCallback = ^NewtonOnJointSerializationCallback;

  NewtonOnJointDeserializationCallback = Procedure(Const body0: pNewtonBody; Const body1: pNewtonBody; functionparam: PNewtonDeserializeCallback; Const serializeHandle: Pointer); cdecl;
  PNewtonOnJointDeserializationCallback = ^NewtonOnJointDeserializationCallback;

  NewtonOnUserCollisionSerializationCallback = Procedure(Const userData: Pointer; functionparam: PNewtonSerializeCallback; Const serializeHandle: Pointer); cdecl;
  PNewtonOnUserCollisionSerializationCallback = ^NewtonOnUserCollisionSerializationCallback;

  NewtonUserMeshCollisionDestroyCallback = Procedure(Const userData: Pointer); cdecl;
  PNewtonUserMeshCollisionDestroyCallback = ^NewtonUserMeshCollisionDestroyCallback;

  NewtonUserMeshCollisionRayHitCallback = Function(Const lineDescData: PNewtonUserMeshCollisionRayHitDesc): dfloat; cdecl;
  PNewtonUserMeshCollisionRayHitCallback = ^NewtonUserMeshCollisionRayHitCallback;

  NewtonUserMeshCollisionGetCollisionInfo = Procedure(Const userData: Pointer; Const infoRecord: PNewtonCollisionInfoRecord); cdecl;
  PNewtonUserMeshCollisionGetCollisionInfo = ^NewtonUserMeshCollisionGetCollisionInfo;

  NewtonUserMeshCollisionAABBTest = Function(Const userData: Pointer; Const boxP0: pfloat; Const boxP1: pfloat): Integer; cdecl;
  PNewtonUserMeshCollisionAABBTest = ^NewtonUserMeshCollisionAABBTest;

  NewtonUserMeshCollisionGetFacesInAABB = Function(Const userData: Pointer; Const p0: pfloat; Const p1: pfloat; Const vertexArray: Pfloat; Const vertexCount: Pinteger; Const vertexStrideInBytes: Pinteger; Const indexList: Pinteger; maxIndexCount: Integer; Const userDataList: Pinteger): Integer; cdecl;
  PNewtonUserMeshCollisionGetFacesInAABB = ^NewtonUserMeshCollisionGetFacesInAABB;

  NewtonUserMeshCollisionCollideCallback = Procedure(Const collideDescData: PNewtonUserMeshCollisionCollideDesc; Const continueCollisionHandle: Pointer); cdecl;
  PNewtonUserMeshCollisionCollideCallback = ^NewtonUserMeshCollisionCollideCallback;

  NewtonTreeCollisionFaceCallback = Function(Const context: Pointer; Const polygon: pfloat; strideInBytes: Integer; Const indexArray: Pinteger; indexCount: Integer): Integer; cdecl;
  PNewtonTreeCollisionFaceCallback = ^NewtonTreeCollisionFaceCallback;

  NewtonCollisionTreeRayCastCallback = Function(Const body: pNewtonBody; Const treeCollision: PNewtonCollision; intersection: dfloat; Const normal: pfloat; faceId: Integer; Const usedData: Pointer): dfloat; cdecl;
  PNewtonCollisionTreeRayCastCallback = ^NewtonCollisionTreeRayCastCallback;

  NewtonHeightFieldRayCastCallback = Function(Const body: pNewtonBody; Const heightFieldCollision: PNewtonCollision; intersection: dfloat; row: Integer; col: Integer; Const normal: pfloat; faceId: Integer; Const usedData: Pointer): dfloat; cdecl;
  PNewtonHeightFieldRayCastCallback = ^NewtonHeightFieldRayCastCallback;

  NewtonCollisionCopyConstructionCallback = Procedure(Const newtonWorld: PNewtonWorld; Const collision: PNewtonCollision; Const sourceCollision: PNewtonCollision); cdecl;
  PNewtonCollisionCopyConstructionCallback = ^NewtonCollisionCopyConstructionCallback;

  NewtonCollisionDestructorCallback = Procedure(Const newtonWorld: PNewtonWorld; Const collision: PNewtonCollision); cdecl;
  PNewtonCollisionDestructorCallback = ^NewtonCollisionDestructorCallback;

  NewtonTreeCollisionCallback = Procedure(Const bodyWithTreeCollision: pNewtonBody; Const body: pNewtonBody; faceID: Integer; vertexCount: Integer; Const vertex: pfloat; vertexStrideInBytes: Integer); cdecl;
  PNewtonTreeCollisionCallback = ^NewtonTreeCollisionCallback;

  NewtonBodyDestructor = Procedure(Const body: pNewtonBody); cdecl;
  PNewtonBodyDestructor = ^NewtonBodyDestructor;

  NewtonApplyForceAndTorque = Procedure(Const body: pNewtonBody; timestep: dfloat; threadIndex: Integer); cdecl;
  PNewtonApplyForceAndTorque = ^NewtonApplyForceAndTorque;

  NewtonSetTransform = Procedure(Const body: pNewtonBody; Const matrix: pfloat; threadIndex: Integer); cdecl;
  PNewtonSetTransform = ^NewtonSetTransform;

  NewtonIslandUpdate = Function(Const newtonWorld: PNewtonWorld; Const islandHandle: Pointer; bodyCount: Integer): Integer; cdecl;
  PNewtonIslandUpdate = ^NewtonIslandUpdate;

  NewtonFractureCompoundCollisionOnEmitCompoundFractured = Procedure(Const fracturedBody: pNewtonBody); cdecl;
  PNewtonFractureCompoundCollisionOnEmitCompoundFractured = ^NewtonFractureCompoundCollisionOnEmitCompoundFractured;

  NewtonFractureCompoundCollisionOnEmitChunk = Procedure(Const chunkBody: pNewtonBody; Const fracturexChunkMesh: PNewtonFracturedCompoundMeshPart; Const fracturedCompountCollision: PNewtonCollision); cdecl;
  PNewtonFractureCompoundCollisionOnEmitChunk = ^NewtonFractureCompoundCollisionOnEmitChunk;

  NewtonFractureCompoundCollisionReconstructMainMeshCallBack = Procedure(Const body: pNewtonBody; Const mainMesh: PNewtonFracturedCompoundMeshPart; Const fracturedCompountCollision: PNewtonCollision); cdecl;
  PNewtonFractureCompoundCollisionReconstructMainMeshCallBack = ^NewtonFractureCompoundCollisionReconstructMainMeshCallBack;

  NewtonWorldRayPrefilterCallback = Function(Const body: pNewtonBody; Const collision: PNewtonCollision; Const userData: Pointer): LongWord; cdecl;
  PNewtonWorldRayPrefilterCallback = ^NewtonWorldRayPrefilterCallback;

  NewtonWorldRayFilterCallback = Function(Const body: pNewtonBody; Const shapeHit: PNewtonCollision; Const hitContact: pfloat; Const hitNormal: pfloat; collisionID: int64; Const userData: Pointer; intersectParam: dfloat): dfloat; cdecl;
  PNewtonWorldRayFilterCallback = ^NewtonWorldRayFilterCallback;

  NewtonOnAABBOverlap = Function(Const contact: PNewtonJoint; timestep: dfloat; threadIndex: Integer): Integer; cdecl;
  PNewtonOnAABBOverlap = ^NewtonOnAABBOverlap;

  NewtonContactsProcess = Procedure(Const contact: PNewtonJoint; timestep: dfloat; threadIndex: Integer); cdecl;
  PNewtonContactsProcess = ^NewtonContactsProcess;

  NewtonOnCompoundSubCollisionAABBOverlap = Function(Const contact: PNewtonJoint; timestep: dfloat; Const body0: pNewtonBody; Const collisionNode0: Pointer; Const body1: pNewtonBody; Const collisionNode1: Pointer; threadIndex: Integer): Integer; cdecl;
  PNewtonOnCompoundSubCollisionAABBOverlap = ^NewtonOnCompoundSubCollisionAABBOverlap;

  NewtonOnContactGeneration = Function(Const material: PNewtonMaterial; Const body0: pNewtonBody; Const collision0: PNewtonCollision; Const body1: pNewtonBody; Const collision1: PNewtonCollision; Const contactBuffer: PNewtonUserContactPoint; maxCount: Integer; threadIndex: Integer): Integer; cdecl;
  PNewtonOnContactGeneration = ^NewtonOnContactGeneration;

  NewtonBodyIterator = Function(Const body: pNewtonBody; Const userData: Pointer): Integer; cdecl;
  PNewtonBodyIterator = ^NewtonBodyIterator;

  NewtonJointIterator = Procedure(Const joint: PNewtonJoint; Const userData: Pointer); cdecl;
  PNewtonJointIterator = ^NewtonJointIterator;

  NewtonCollisionIterator = Procedure(Const userData: Pointer; vertexCount: Integer; Const faceArray: pfloat; faceId: Integer); cdecl;
  PNewtonCollisionIterator = ^NewtonCollisionIterator;

  NewtonBallCallback = Procedure(Const ball: PNewtonJoint; timestep: dfloat); cdecl;
  PNewtonBallCallback = ^NewtonBallCallback;

  NewtonHingeCallback = Function(Const hinge: PNewtonJoint; Const desc: PNewtonHingeSliderUpdateDesc): LongWord; cdecl;
  PNewtonHingeCallback = ^NewtonHingeCallback;

  NewtonSliderCallback = Function(Const slider: PNewtonJoint; Const desc: PNewtonHingeSliderUpdateDesc): LongWord; cdecl;
  PNewtonSliderCallback = ^NewtonSliderCallback;

  NewtonUniversalCallback = Function(Const universal: PNewtonJoint; Const desc: PNewtonHingeSliderUpdateDesc): LongWord; cdecl;
  PNewtonUniversalCallback = ^NewtonUniversalCallback;

  NewtonCorkscrewCallback = Function(Const corkscrew: PNewtonJoint; Const desc: PNewtonHingeSliderUpdateDesc): LongWord; cdecl;
  PNewtonCorkscrewCallback = ^NewtonCorkscrewCallback;

  NewtonUserBilateralCallback = Procedure(Const userJoint: PNewtonJoint; timestep: dfloat; threadIndex: Integer); cdecl;
  PNewtonUserBilateralCallback = ^NewtonUserBilateralCallback;

  NewtonUserBilateralGetInfoCallback = Procedure(Const userJoint: PNewtonJoint; Const info: PNewtonJointRecord); cdecl;
  PNewtonUserBilateralGetInfoCallback = ^NewtonUserBilateralGetInfoCallback;

  NewtonConstraintDestructor = Procedure(Const me: PNewtonJoint); cdecl;
  PNewtonConstraintDestructor = ^NewtonConstraintDestructor;

  NewtonJobTask = Procedure(Const world: PNewtonWorld; Const userData: Pointer; threadIndex: Integer); cdecl;
  PNewtonJobTask = ^NewtonJobTask;

  NewtonReportProgress = Function(normalizedProgressPercent: dfloat; Const userData: Pointer): Integer; cdecl;
  PNewtonReportProgress = ^NewtonReportProgress;

  { world control functions }
Function NewtonWorldGetVersion(): Integer; cdecl; external newtondll;
Function NewtonWorldFloatSize(): Integer; cdecl; external newtondll;
Function NewtonGetMemoryUsed(): Integer; cdecl; external newtondll;
Procedure NewtonSetMemorySystem(malloc: NewtonAllocMemory; free: NewtonFreeMemory); cdecl; external newtondll;
Function NewtonCreate(): PNewtonWorld; cdecl; external newtondll;
Procedure NewtonDestroy(Const newtonWorld: PNewtonWorld); cdecl; external newtondll;
Procedure NewtonDestroyAllBodies(Const newtonWorld: PNewtonWorld); cdecl; external newtondll;
Function NewtonGetPostUpdateCallback(Const newtonWorld: PNewtonWorld): PNewtonPostUpdateCallback; cdecl; external newtondll;
Procedure NewtonSetPostUpdateCallback(Const newtonWorld: PNewtonWorld; callback: NewtonPostUpdateCallback); cdecl; external newtondll;
Function NewtonAlloc(sizeInBytes: Integer): Pointer; cdecl; external newtondll;
Procedure NewtonFree(Const ptr: Pointer); cdecl; external newtondll;
Procedure NewtonLoadPlugins(Const newtonWorld: PNewtonWorld; Const plugInPath: pchar); cdecl; external newtondll;
Procedure NewtonUnloadPlugins(Const newtonWorld: PNewtonWorld); cdecl; external newtondll;
Function NewtonCurrentPlugin(Const newtonWorld: PNewtonWorld): Pointer; cdecl; external newtondll;
Function NewtonGetFirstPlugin(Const newtonWorld: PNewtonWorld): Pointer; cdecl; external newtondll;
Function NewtonGetPreferedPlugin(Const newtonWorld: PNewtonWorld): Pointer; cdecl; external newtondll;
Function NewtonGetNextPlugin(Const newtonWorld: PNewtonWorld; Const plugin: Pointer): Pointer; cdecl; external newtondll;
Function NewtonGetPluginString(Const newtonWorld: PNewtonWorld; Const plugin: Pointer): pchar; cdecl; external newtondll;
Procedure NewtonSelectPlugin(Const newtonWorld: PNewtonWorld; Const plugin: Pointer); cdecl; external newtondll;
Function NewtonGetContactMergeTolerance(Const newtonWorld: PNewtonWorld): dfloat; cdecl; external newtondll;
Procedure NewtonSetContactMergeTolerance(Const newtonWorld: PNewtonWorld; tolerance: dfloat); cdecl; external newtondll;
Procedure NewtonInvalidateCache(Const newtonWorld: PNewtonWorld); cdecl; external newtondll;
Procedure NewtonSetSolverIterations(Const newtonWorld: PNewtonWorld; model: Integer); cdecl; external newtondll;
Function NewtonGetSolverIterations(Const newtonWorld: PNewtonWorld): Integer; cdecl; external newtondll;
Procedure NewtonSetParallelSolverOnLargeIsland(Const newtonWorld: PNewtonWorld; mode: Integer); cdecl; external newtondll;
Function NewtonGetParallelSolverOnLargeIsland(Const newtonWorld: PNewtonWorld): Integer; cdecl; external newtondll;
Function NewtonGetBroadphaseAlgorithm(Const newtonWorld: PNewtonWorld): Integer; cdecl; external newtondll;
Procedure NewtonSelectBroadphaseAlgorithm(Const newtonWorld: PNewtonWorld; algorithmType: Integer); cdecl; external newtondll;
Procedure NewtonResetBroadphase(Const newtonWorld: PNewtonWorld); cdecl; external newtondll;
Procedure NewtonUpdate(Const newtonWorld: PNewtonWorld; timestep: dfloat); cdecl; external newtondll;
Procedure NewtonUpdateAsync(Const newtonWorld: PNewtonWorld; timestep: dfloat); cdecl; external newtondll;
Procedure NewtonWaitForUpdateToFinish(Const newtonWorld: PNewtonWorld); cdecl; external newtondll;
Function NewtonGetNumberOfSubsteps(Const newtonWorld: PNewtonWorld): Integer; cdecl; external newtondll;
Procedure NewtonSetNumberOfSubsteps(Const newtonWorld: PNewtonWorld; subSteps: Integer); cdecl; external newtondll;
Function NewtonGetLastUpdateTime(Const newtonWorld: PNewtonWorld): dfloat; cdecl; external newtondll;
Procedure NewtonSerializeToFile(Const newtonWorld: PNewtonWorld; Const filename: pchar; bodyCallback: NewtonOnBodySerializationCallback; Const bodyUserData: Pointer); cdecl; external newtondll;
Procedure NewtonDeserializeFromFile(Const newtonWorld: PNewtonWorld; Const filename: pchar; bodyCallback: NewtonOnBodyDeserializationCallback; Const bodyUserData: Pointer); cdecl; external newtondll;
Procedure NewtonSerializeScene(Const newtonWorld: PNewtonWorld; bodyCallback: NewtonOnBodySerializationCallback; Const bodyUserData: Pointer; serializeCallback: NewtonSerializeCallback; Const serializeHandle: Pointer); cdecl; external newtondll;
Procedure NewtonDeserializeScene(Const newtonWorld: PNewtonWorld; bodyCallback: NewtonOnBodyDeserializationCallback; Const bodyUserData: Pointer; serializeCallback: NewtonDeserializeCallback; Const serializeHandle: Pointer); cdecl; external newtondll;
Function NewtonFindSerializedBody(Const newtonWorld: PNewtonWorld; bodySerializedID: Integer): pNewtonBody; cdecl; external newtondll;
Procedure NewtonSetJointSerializationCallbacks(Const newtonWorld: PNewtonWorld; serializeJoint: NewtonOnJointSerializationCallback; deserializeJoint: NewtonOnJointDeserializationCallback); cdecl; external newtondll;
Procedure NewtonGetJointSerializationCallbacks(Const newtonWorld: PNewtonWorld; Const serializeJoint: NewtonOnJointSerializationCallback; Const deserializeJoint: NewtonOnJointDeserializationCallback); cdecl; external newtondll;
Procedure NewtonWorldCriticalSectionLock(Const newtonWorld: PNewtonWorld; threadIndex: Integer); cdecl; external newtondll;
Procedure NewtonWorldCriticalSectionUnlock(Const newtonWorld: PNewtonWorld); cdecl; external newtondll;
Procedure NewtonSetThreadsCount(Const newtonWorld: PNewtonWorld; threads: Integer); cdecl; external newtondll;
Function NewtonGetThreadsCount(Const newtonWorld: PNewtonWorld): Integer; cdecl; external newtondll;
Function NewtonGetMaxThreadsCount(Const newtonWorld: PNewtonWorld): Integer; cdecl; external newtondll;
Procedure NewtonDispachThreadJob(Const newtonWorld: PNewtonWorld; task: NewtonJobTask; Const usedData: Pointer; Const functionName: pchar); cdecl; external newtondll;
Procedure NewtonSyncThreadJobs(Const newtonWorld: PNewtonWorld); cdecl; external newtondll;
Function NewtonAtomicAdd(Const ptr: Pinteger; value: Integer): Integer; cdecl; external newtondll;
Function NewtonAtomicSwap(Const ptr: Pinteger; value: Integer): Integer; cdecl; external newtondll;
Procedure NewtonYield(); cdecl; external newtondll;
Procedure NewtonSetIslandUpdateEvent(Const newtonWorld: PNewtonWorld; islandUpdate: NewtonIslandUpdate); cdecl; external newtondll;
Procedure NewtonWorldForEachJointDo(Const newtonWorld: PNewtonWorld; callback: NewtonJointIterator; Const userData: Pointer); cdecl; external newtondll;
Procedure NewtonWorldForEachBodyInAABBDo(Const newtonWorld: PNewtonWorld; Const p0: pfloat; Const p1: pfloat; callback: NewtonBodyIterator; Const userData: Pointer); cdecl; external newtondll;
Procedure NewtonWorldSetUserData(Const newtonWorld: PNewtonWorld; Const userData: Pointer); cdecl; external newtondll;
Function NewtonWorldGetUserData(Const newtonWorld: PNewtonWorld): Pointer; cdecl; external newtondll;
Function NewtonWorldAddListener(Const newtonWorld: PNewtonWorld; Const nameId: pchar; Const listenerUserData: Pointer): Pointer; cdecl; external newtondll;
Function NewtonWorldGetListener(Const newtonWorld: PNewtonWorld; Const nameId: pchar): Pointer; cdecl; external newtondll;
Procedure NewtonWorldListenerSetDebugCallback(Const newtonWorld: PNewtonWorld; Const listener: Pointer; callback: NewtonWorldListenerDebugCallback); cdecl; external newtondll;
Procedure NewtonWorldListenerSetPostStepCallback(Const newtonWorld: PNewtonWorld; Const listener: Pointer; callback: NewtonWorldUpdateListenerCallback); cdecl; external newtondll;
Procedure NewtonWorldListenerSetPreUpdateCallback(Const newtonWorld: PNewtonWorld; Const listener: Pointer; callback: NewtonWorldUpdateListenerCallback); cdecl; external newtondll;
Procedure NewtonWorldListenerSetPostUpdateCallback(Const newtonWorld: PNewtonWorld; Const listener: Pointer; callback: NewtonWorldUpdateListenerCallback); cdecl; external newtondll;
Procedure NewtonWorldListenerSetDestructorCallback(Const newtonWorld: PNewtonWorld; Const listener: Pointer; callback: NewtonWorldDestroyListenerCallback); cdecl; external newtondll;
Procedure NewtonWorldListenerSetBodyDestroyCallback(Const newtonWorld: PNewtonWorld; Const listener: Pointer; callback: NewtonWorldListenerBodyDestroyCallback); cdecl; external newtondll;
Procedure NewtonWorldListenerDebug(Const newtonWorld: PNewtonWorld; Const context: Pointer); cdecl; external newtondll;
Function NewtonWorldGetListenerUserData(Const newtonWorld: PNewtonWorld; Const listener: Pointer): Pointer; cdecl; external newtondll;
Function NewtonWorldListenerGetBodyDestroyCallback(Const newtonWorld: PNewtonWorld; Const listener: Pointer): PNewtonWorldListenerBodyDestroyCallback; cdecl; external newtondll;
Procedure NewtonWorldSetDestructorCallback(Const newtonWorld: PNewtonWorld; destructorparam: NewtonWorldDestructorCallback); cdecl; external newtondll;
Function NewtonWorldGetDestructorCallback(Const newtonWorld: PNewtonWorld): PNewtonWorldDestructorCallback; cdecl; external newtondll;
Procedure NewtonWorldSetCollisionConstructorDestructorCallback(Const newtonWorld: PNewtonWorld; constructorparam: NewtonCollisionCopyConstructionCallback; destructorparam: NewtonCollisionDestructorCallback); cdecl; external newtondll;
Procedure NewtonWorldSetCreateDestroyContactCallback(Const newtonWorld: PNewtonWorld; createContact: NewtonCreateContactCallback; destroyContact: NewtonDestroyContactCallback); cdecl; external newtondll;
Procedure NewtonWorldRayCast(Const newtonWorld: PNewtonWorld; Const p0: pfloat; Const p1: pfloat; filter: NewtonWorldRayFilterCallback; Const userData: Pointer; prefilter: NewtonWorldRayPrefilterCallback; threadIndex: Integer); cdecl; external newtondll;
Function NewtonWorldConvexCast(Const newtonWorld: PNewtonWorld; Const matrix: pfloat; Const target: pfloat; Const shape: PNewtonCollision; Const param: pfloat; Const userData: Pointer; prefilter: NewtonWorldRayPrefilterCallback; Const info: PNewtonWorldConvexCastReturnInfo; maxContactsCount: Integer; threadIndex: Integer): Integer; cdecl; external newtondll;
Function NewtonWorldCollide(Const newtonWorld: PNewtonWorld; Const matrix: pfloat; Const shape: PNewtonCollision; Const userData: Pointer; prefilter: NewtonWorldRayPrefilterCallback; Const info: PNewtonWorldConvexCastReturnInfo; maxContactsCount: Integer; threadIndex: Integer): Integer; cdecl; external newtondll;
Function NewtonWorldGetBodyCount(Const newtonWorld: PNewtonWorld): Integer; cdecl; external newtondll;
Function NewtonWorldGetConstraintCount(Const newtonWorld: PNewtonWorld): Integer; cdecl; external newtondll;
Function NewtonWorldFindJoint(Const body0: pNewtonBody; Const body1: pNewtonBody): PNewtonJoint; cdecl; external newtondll;
{ Simulation islands }
Function NewtonIslandGetBody(Const island: Pointer; bodyIndex: Integer): pNewtonBody; cdecl; external newtondll;
Procedure NewtonIslandGetBodyAABB(Const island: Pointer; bodyIndex: Integer; Const p0: pfloat; Const p1: pfloat); cdecl; external newtondll;
{ Physics Material Section }
Function NewtonMaterialCreateGroupID(Const newtonWorld: PNewtonWorld): Integer; cdecl; external newtondll;
Function NewtonMaterialGetDefaultGroupID(Const newtonWorld: PNewtonWorld): Integer; cdecl; external newtondll;
Procedure NewtonMaterialDestroyAllGroupID(Const newtonWorld: PNewtonWorld); cdecl; external newtondll;
Function NewtonMaterialGetUserData(Const newtonWorld: PNewtonWorld; id0: Integer; id1: Integer): Pointer; cdecl; external newtondll;
Procedure NewtonMaterialSetSurfaceThickness(Const newtonWorld: PNewtonWorld; id0: Integer; id1: Integer; thickness: dfloat); cdecl; external newtondll;
Procedure NewtonMaterialSetCallbackUserData(Const newtonWorld: PNewtonWorld; id0: Integer; id1: Integer; Const userData: Pointer); cdecl; external newtondll;
Procedure NewtonMaterialSetContactGenerationCallback(Const newtonWorld: PNewtonWorld; id0: Integer; id1: Integer; contactGeneration: NewtonOnContactGeneration); cdecl; external newtondll;
Procedure NewtonMaterialSetCompoundCollisionCallback(Const newtonWorld: PNewtonWorld; id0: Integer; id1: Integer; compoundAabbOverlap: NewtonOnCompoundSubCollisionAABBOverlap); cdecl; external newtondll;
Procedure NewtonMaterialSetCollisionCallback(Const newtonWorld: PNewtonWorld; id0: Integer; id1: Integer; aabbOverlap: NewtonOnAABBOverlap; process: NewtonContactsProcess); cdecl; external newtondll;
Procedure NewtonMaterialSetDefaultSoftness(Const newtonWorld: PNewtonWorld; id0: Integer; id1: Integer; value: dfloat); cdecl; external newtondll;
Procedure NewtonMaterialSetDefaultElasticity(Const newtonWorld: PNewtonWorld; id0: Integer; id1: Integer; elasticCoef: dfloat); cdecl; external newtondll;
Procedure NewtonMaterialSetDefaultCollidable(Const newtonWorld: PNewtonWorld; id0: Integer; id1: Integer; state: Integer); cdecl; external newtondll;
Procedure NewtonMaterialSetDefaultFriction(Const newtonWorld: PNewtonWorld; id0: Integer; id1: Integer; staticFriction: dfloat; kineticFriction: dfloat); cdecl; external newtondll;
Procedure NewtonMaterialJointResetIntraJointCollision(Const newtonWorld: PNewtonWorld; id0: Integer; id1: Integer); cdecl; external newtondll;
Procedure NewtonMaterialJointResetSelftJointCollision(Const newtonWorld: PNewtonWorld; id0: Integer; id1: Integer); cdecl; external newtondll;
Function NewtonWorldGetFirstMaterial(Const newtonWorld: PNewtonWorld): PNewtonMaterial; cdecl; external newtondll;
Function NewtonWorldGetNextMaterial(Const newtonWorld: PNewtonWorld; Const material: PNewtonMaterial): PNewtonMaterial; cdecl; external newtondll;
Function NewtonWorldGetFirstBody(Const newtonWorld: PNewtonWorld): pNewtonBody; cdecl; external newtondll;
Function NewtonWorldGetNextBody(Const newtonWorld: PNewtonWorld; Const curBody: pNewtonBody): pNewtonBody; cdecl; external newtondll;
{ Physics Contact control functions }
Function NewtonMaterialGetMaterialPairUserData(Const material: PNewtonMaterial): Pointer; cdecl; external newtondll;
Function NewtonMaterialGetContactFaceAttribute(Const material: PNewtonMaterial): LongWord; cdecl; external newtondll;
Function NewtonMaterialGetBodyCollidingShape(Const material: PNewtonMaterial; Const body: pNewtonBody): PNewtonCollision; cdecl; external newtondll;
Function NewtonMaterialGetContactNormalSpeed(Const material: PNewtonMaterial): dfloat; cdecl; external newtondll;
Procedure NewtonMaterialGetContactForce(Const material: PNewtonMaterial; Const body: pNewtonBody; Const force: pfloat); cdecl; external newtondll;
Procedure NewtonMaterialGetContactPositionAndNormal(Const material: PNewtonMaterial; Const body: pNewtonBody; Const posit: pfloat; Const normal: pfloat); cdecl; external newtondll;
Procedure NewtonMaterialGetContactTangentDirections(Const material: PNewtonMaterial; Const body: pNewtonBody; Const dir0: pfloat; Const dir1: pfloat); cdecl; external newtondll;
Function NewtonMaterialGetContactTangentSpeed(Const material: PNewtonMaterial; index: Integer): dfloat; cdecl; external newtondll;
Function NewtonMaterialGetContactMaxNormalImpact(Const material: PNewtonMaterial): dfloat; cdecl; external newtondll;
Function NewtonMaterialGetContactMaxTangentImpact(Const material: PNewtonMaterial; index: Integer): dfloat; cdecl; external newtondll;
Function NewtonMaterialGetContactPenetration(Const material: PNewtonMaterial): dfloat; cdecl; external newtondll;
Procedure NewtonMaterialSetAsSoftContact(Const material: PNewtonMaterial; relaxation: dfloat); cdecl; external newtondll;
Procedure NewtonMaterialSetContactSoftness(Const material: PNewtonMaterial; softness: dfloat); cdecl; external newtondll;
Procedure NewtonMaterialSetContactThickness(Const material: PNewtonMaterial; thickness: dfloat); cdecl; external newtondll;
Procedure NewtonMaterialSetContactElasticity(Const material: PNewtonMaterial; restitution: dfloat); cdecl; external newtondll;
Procedure NewtonMaterialSetContactFrictionState(Const material: PNewtonMaterial; state: Integer; index: Integer); cdecl; external newtondll;
Procedure NewtonMaterialSetContactFrictionCoef(Const material: PNewtonMaterial; staticFrictionCoef: dfloat; kineticFrictionCoef: dfloat; index: Integer); cdecl; external newtondll;
Procedure NewtonMaterialSetContactNormalAcceleration(Const material: PNewtonMaterial; accel: dfloat); cdecl; external newtondll;
Procedure NewtonMaterialSetContactNormalDirection(Const material: PNewtonMaterial; Const directionVector: pfloat); cdecl; external newtondll;
Procedure NewtonMaterialSetContactPosition(Const material: PNewtonMaterial; Const position: pfloat); cdecl; external newtondll;
Procedure NewtonMaterialSetContactTangentFriction(Const material: PNewtonMaterial; friction: dfloat; index: Integer); cdecl; external newtondll;
Procedure NewtonMaterialSetContactTangentAcceleration(Const material: PNewtonMaterial; accel: dfloat; index: Integer); cdecl; external newtondll;
Procedure NewtonMaterialContactRotateTangentDirections(Const material: PNewtonMaterial; Const directionVector: pfloat); cdecl; external newtondll;
Function NewtonMaterialGetContactPruningTolerance(Const contactJoint: PNewtonJoint): dfloat; cdecl; external newtondll;
Procedure NewtonMaterialSetContactPruningTolerance(Const contactJoint: PNewtonJoint; tolerance: dfloat); cdecl; external newtondll;
{ convex collision primitives creation functions }
Function NewtonCreateNull(Const newtonWorld: PNewtonWorld): PNewtonCollision; cdecl; external newtondll;
Function NewtonCreateSphere(Const newtonWorld: PNewtonWorld; radius: dfloat; shapeID: Integer; Const offsetMatrix: pfloat): PNewtonCollision; cdecl; external newtondll;
Function NewtonCreateBox(Const newtonWorld: PNewtonWorld; dx: dfloat; dy: dfloat; dz: dfloat; shapeID: Integer; Const offsetMatrix: pfloat): PNewtonCollision; cdecl; external newtondll;
Function NewtonCreateCone(Const newtonWorld: PNewtonWorld; radius: dfloat; height: dfloat; shapeID: Integer; Const offsetMatrix: pfloat): PNewtonCollision; cdecl; external newtondll;
Function NewtonCreateCapsule(Const newtonWorld: PNewtonWorld; radius0: dfloat; radius1: dfloat; height: dfloat; shapeID: Integer; Const offsetMatrix: pfloat): PNewtonCollision; cdecl; external newtondll;
Function NewtonCreateCylinder(Const newtonWorld: PNewtonWorld; radio0: dfloat; radio1: dfloat; height: dfloat; shapeID: Integer; Const offsetMatrix: pfloat): PNewtonCollision; cdecl; external newtondll;
Function NewtonCreateChamferCylinder(Const newtonWorld: PNewtonWorld; radius: dfloat; height: dfloat; shapeID: Integer; Const offsetMatrix: pfloat): PNewtonCollision; cdecl; external newtondll;
Function NewtonCreateConvexHull(Const newtonWorld: PNewtonWorld; count: Integer; Const vertexCloud: pfloat; strideInBytes: Integer; tolerance: dfloat; shapeID: Integer; Const offsetMatrix: pfloat): PNewtonCollision; cdecl; external newtondll;
Function NewtonCreateConvexHullFromMesh(Const newtonWorld: PNewtonWorld; Const mesh: PNewtonMesh; tolerance: dfloat; shapeID: Integer): PNewtonCollision; cdecl; external newtondll;
Function NewtonCollisionGetMode(Const convexCollision: PNewtonCollision): Integer; cdecl; external newtondll;
Procedure NewtonCollisionSetMode(Const convexCollision: PNewtonCollision; mode: Integer); cdecl; external newtondll;
Function NewtonConvexHullGetFaceIndices(Const convexHullCollision: PNewtonCollision; face: Integer; Const faceIndices: Pinteger): Integer; cdecl; external newtondll;
Function NewtonConvexHullGetVertexData(Const convexHullCollision: PNewtonCollision; Const vertexData: Pfloat; strideInBytes: Pinteger): Integer; cdecl; external newtondll;
Function NewtonConvexCollisionCalculateVolume(Const convexCollision: PNewtonCollision): dfloat; cdecl; external newtondll;
Procedure NewtonConvexCollisionCalculateInertialMatrix(Const convexCollision: PNewtonCollision; Const inertia: pfloat; Const origin: pfloat); cdecl; external newtondll;
Function NewtonConvexCollisionCalculateBuoyancyVolume(Const convexCollision: PNewtonCollision; Const matrix: pfloat; Const fluidPlane: pfloat; Const centerOfBuoyancy: pfloat): dfloat; cdecl; external newtondll;
Function NewtonCollisionDataPointer(Const convexCollision: PNewtonCollision): Pointer; cdecl; external newtondll;
{ compound collision primitives creation functions }
Function NewtonCreateCompoundCollision(Const newtonWorld: PNewtonWorld; shapeID: Integer): PNewtonCollision; cdecl; external newtondll;
Function NewtonCreateCompoundCollisionFromMesh(Const newtonWorld: PNewtonWorld; Const mesh: PNewtonMesh; hullTolerance: dfloat; shapeID: Integer; subShapeID: Integer): PNewtonCollision; cdecl; external newtondll;
Procedure NewtonCompoundCollisionBeginAddRemove(Const compoundCollision: PNewtonCollision); cdecl; external newtondll;
Function NewtonCompoundCollisionAddSubCollision(Const compoundCollision: PNewtonCollision; Const convexCollision: PNewtonCollision): Pointer; cdecl; external newtondll;
Procedure NewtonCompoundCollisionRemoveSubCollision(Const compoundCollision: PNewtonCollision; Const collisionNode: Pointer); cdecl; external newtondll;
Procedure NewtonCompoundCollisionRemoveSubCollisionByIndex(Const compoundCollision: PNewtonCollision; nodeIndex: Integer); cdecl; external newtondll;
Procedure NewtonCompoundCollisionSetSubCollisionMatrix(Const compoundCollision: PNewtonCollision; Const collisionNode: Pointer; Const matrix: pfloat); cdecl; external newtondll;
Procedure NewtonCompoundCollisionEndAddRemove(Const compoundCollision: PNewtonCollision); cdecl; external newtondll;
Function NewtonCompoundCollisionGetFirstNode(Const compoundCollision: PNewtonCollision): Pointer; cdecl; external newtondll;
Function NewtonCompoundCollisionGetNextNode(Const compoundCollision: PNewtonCollision; Const collisionNode: Pointer): Pointer; cdecl; external newtondll;
Function NewtonCompoundCollisionGetNodeByIndex(Const compoundCollision: PNewtonCollision; index: Integer): Pointer; cdecl; external newtondll;
Function NewtonCompoundCollisionGetNodeIndex(Const compoundCollision: PNewtonCollision; Const collisionNode: Pointer): Integer; cdecl; external newtondll;
Function NewtonCompoundCollisionGetCollisionFromNode(Const compoundCollision: PNewtonCollision; Const collisionNode: Pointer): PNewtonCollision; cdecl; external newtondll;
{ Fractured compound collision primitives interface }
Function NewtonCreateFracturedCompoundCollision(Const newtonWorld: PNewtonWorld; Const solidMesh: PNewtonMesh; shapeID: Integer; fracturePhysicsMaterialID: Integer; pointcloudCount: Integer; Const vertexCloud: pfloat; strideInBytes: Integer; materialID: Integer; Const textureMatrix: pfloat; regenerateMainMeshCallback: NewtonFractureCompoundCollisionReconstructMainMeshCallBack; emitFracturedCompound: NewtonFractureCompoundCollisionOnEmitCompoundFractured; emitFracfuredChunk: NewtonFractureCompoundCollisionOnEmitChunk): PNewtonCollision; cdecl; external newtondll;
Function NewtonFracturedCompoundPlaneClip(Const fracturedCompound: PNewtonCollision; Const plane: pfloat): PNewtonCollision; cdecl; external newtondll;
Procedure NewtonFracturedCompoundSetCallbacks(Const fracturedCompound: PNewtonCollision; regenerateMainMeshCallback: NewtonFractureCompoundCollisionReconstructMainMeshCallBack; emitFracturedCompound: NewtonFractureCompoundCollisionOnEmitCompoundFractured; emitFracfuredChunk: NewtonFractureCompoundCollisionOnEmitChunk); cdecl; external newtondll;
Function NewtonFracturedCompoundIsNodeFreeToDetach(Const fracturedCompound: PNewtonCollision; Const collisionNode: Pointer): Integer; cdecl; external newtondll;
Function NewtonFracturedCompoundNeighborNodeList(Const fracturedCompound: PNewtonCollision; Const collisionNode: Pointer; Const list: PPointer; maxCount: Integer): Integer; cdecl; external newtondll;
Function NewtonFracturedCompoundGetMainMesh(Const fracturedCompound: PNewtonCollision): PNewtonFracturedCompoundMeshPart; cdecl; external newtondll;
Function NewtonFracturedCompoundGetFirstSubMesh(Const fracturedCompound: PNewtonCollision): PNewtonFracturedCompoundMeshPart; cdecl; external newtondll;
Function NewtonFracturedCompoundGetNextSubMesh(Const fracturedCompound: PNewtonCollision; Const subMesh: PNewtonFracturedCompoundMeshPart): PNewtonFracturedCompoundMeshPart; cdecl; external newtondll;
Function NewtonFracturedCompoundCollisionGetVertexCount(Const fracturedCompound: PNewtonCollision; Const meshOwner: PNewtonFracturedCompoundMeshPart): Integer; cdecl; external newtondll;
Function NewtonFracturedCompoundCollisionGetVertexPositions(Const fracturedCompound: PNewtonCollision; Const meshOwner: PNewtonFracturedCompoundMeshPart): pfloat; cdecl; external newtondll;
Function NewtonFracturedCompoundCollisionGetVertexNormals(Const fracturedCompound: PNewtonCollision; Const meshOwner: PNewtonFracturedCompoundMeshPart): pfloat; cdecl; external newtondll;
Function NewtonFracturedCompoundCollisionGetVertexUVs(Const fracturedCompound: PNewtonCollision; Const meshOwner: PNewtonFracturedCompoundMeshPart): pfloat; cdecl; external newtondll;
Function NewtonFracturedCompoundMeshPartGetIndexStream(Const fracturedCompound: PNewtonCollision; Const meshOwner: PNewtonFracturedCompoundMeshPart; Const segment: Pointer; Const index: Pinteger): Integer; cdecl; external newtondll;
Function NewtonFracturedCompoundMeshPartGetFirstSegment(Const fractureCompoundMeshPart: PNewtonFracturedCompoundMeshPart): Pointer; cdecl; external newtondll;
Function NewtonFracturedCompoundMeshPartGetNextSegment(Const fractureCompoundMeshSegment: Pointer): Pointer; cdecl; external newtondll;
Function NewtonFracturedCompoundMeshPartGetMaterial(Const fractureCompoundMeshSegment: Pointer): Integer; cdecl; external newtondll;
Function NewtonFracturedCompoundMeshPartGetIndexCount(Const fractureCompoundMeshSegment: Pointer): Integer; cdecl; external newtondll;
{ scene collision are static compound collision that can take polygonal static collisions }
Function NewtonCreateSceneCollision(Const newtonWorld: PNewtonWorld; shapeID: Integer): PNewtonCollision; cdecl; external newtondll;
Procedure NewtonSceneCollisionBeginAddRemove(Const sceneCollision: PNewtonCollision); cdecl; external newtondll;
Function NewtonSceneCollisionAddSubCollision(Const sceneCollision: PNewtonCollision; Const collision: PNewtonCollision): Pointer; cdecl; external newtondll;
Procedure NewtonSceneCollisionRemoveSubCollision(Const compoundCollision: PNewtonCollision; Const collisionNode: Pointer); cdecl; external newtondll;
Procedure NewtonSceneCollisionRemoveSubCollisionByIndex(Const sceneCollision: PNewtonCollision; nodeIndex: Integer); cdecl; external newtondll;
Procedure NewtonSceneCollisionSetSubCollisionMatrix(Const sceneCollision: PNewtonCollision; Const collisionNode: Pointer; Const matrix: pfloat); cdecl; external newtondll;
Procedure NewtonSceneCollisionEndAddRemove(Const sceneCollision: PNewtonCollision); cdecl; external newtondll;
Function NewtonSceneCollisionGetFirstNode(Const sceneCollision: PNewtonCollision): Pointer; cdecl; external newtondll;
Function NewtonSceneCollisionGetNextNode(Const sceneCollision: PNewtonCollision; Const collisionNode: Pointer): Pointer; cdecl; external newtondll;
Function NewtonSceneCollisionGetNodeByIndex(Const sceneCollision: PNewtonCollision; index: Integer): Pointer; cdecl; external newtondll;
Function NewtonSceneCollisionGetNodeIndex(Const sceneCollision: PNewtonCollision; Const collisionNode: Pointer): Integer; cdecl; external newtondll;
Function NewtonSceneCollisionGetCollisionFromNode(Const sceneCollision: PNewtonCollision; Const collisionNode: Pointer): PNewtonCollision; cdecl; external newtondll;
{ User Static mesh collision interface }
Function NewtonCreateUserMeshCollision(Const newtonWorld: PNewtonWorld; Const minBox: pfloat; Const maxBox: pfloat; Const userData: Pointer; collideCallback: NewtonUserMeshCollisionCollideCallback; rayHitCallback: NewtonUserMeshCollisionRayHitCallback; destroyCallback: NewtonUserMeshCollisionDestroyCallback; getInfoCallback: NewtonUserMeshCollisionGetCollisionInfo; getLocalAABBCallback: NewtonUserMeshCollisionAABBTest; facesInAABBCallback: NewtonUserMeshCollisionGetFacesInAABB; serializeCallback: NewtonOnUserCollisionSerializationCallback; shapeID: Integer): PNewtonCollision; cdecl; external newtondll;
Function NewtonUserMeshCollisionContinuousOverlapTest(Const collideDescData: PNewtonUserMeshCollisionCollideDesc; Const continueCollisionHandle: Pointer; Const minAabb: pfloat; Const maxAabb: pfloat): Integer; cdecl; external newtondll;
{ Collision serialization functions }
Function NewtonCreateCollisionFromSerialization(Const newtonWorld: PNewtonWorld; deserializeFunction: NewtonDeserializeCallback; Const serializeHandle: Pointer): PNewtonCollision; cdecl; external newtondll;
Procedure NewtonCollisionSerialize(Const newtonWorld: PNewtonWorld; Const collision: PNewtonCollision; serializeFunction: NewtonSerializeCallback; Const serializeHandle: Pointer); cdecl; external newtondll;
Procedure NewtonCollisionGetInfo(Const collision: PNewtonCollision; Const collisionInfo: PNewtonCollisionInfoRecord); cdecl; external newtondll;
{ Static collision shapes functions }
Function NewtonCreateHeightFieldCollision(Const newtonWorld: PNewtonWorld; width: Integer; height: Integer; gridsDiagonals: Integer; elevationdatType: Integer; Const elevationMap: Pointer; Const attributeMap: pchar; verticalScale: dfloat; horizontalScale_x: dfloat; horizontalScale_z: dfloat; shapeID: Integer): PNewtonCollision; cdecl; external newtondll;
Procedure NewtonHeightFieldSetUserRayCastCallback(Const heightfieldCollision: PNewtonCollision; rayHitCallback: NewtonHeightFieldRayCastCallback); cdecl; external newtondll;
Function NewtonCreateTreeCollision(Const newtonWorld: PNewtonWorld; shapeID: Integer): PNewtonCollision; cdecl; external newtondll;
Function NewtonCreateTreeCollisionFromMesh(Const newtonWorld: PNewtonWorld; Const mesh: PNewtonMesh; shapeID: Integer): PNewtonCollision; cdecl; external newtondll;
Procedure NewtonTreeCollisionSetUserRayCastCallback(Const treeCollision: PNewtonCollision; rayHitCallback: NewtonCollisionTreeRayCastCallback); cdecl; external newtondll;
Procedure NewtonTreeCollisionBeginBuild(Const treeCollision: PNewtonCollision); cdecl; external newtondll;
Procedure NewtonTreeCollisionAddFace(Const treeCollision: PNewtonCollision; vertexCount: Integer; Const vertexPtr: pfloat; strideInBytes: Integer; faceAttribute: Integer); cdecl; external newtondll;
Procedure NewtonTreeCollisionEndBuild(Const treeCollision: PNewtonCollision; optimize: Integer); cdecl; external newtondll;
Function NewtonTreeCollisionGetFaceAttribute(Const treeCollision: PNewtonCollision; Const faceIndexArray: Pinteger; indexCount: Integer): Integer; cdecl; external newtondll;
Procedure NewtonTreeCollisionSetFaceAttribute(Const treeCollision: PNewtonCollision; Const faceIndexArray: Pinteger; indexCount: Integer; attribute: Integer); cdecl; external newtondll;
Procedure NewtonTreeCollisionForEachFace(Const treeCollision: PNewtonCollision; forEachFaceCallback: NewtonTreeCollisionFaceCallback; Const context: Pointer); cdecl; external newtondll;
Function NewtonTreeCollisionGetVertexListTriangleListInAABB(Const treeCollision: PNewtonCollision; Const p0: pfloat; Const p1: pfloat; Const vertexArray: Pfloat; Const vertexCount: Pinteger; Const vertexStrideInBytes: Pinteger; Const indexList: Pinteger; maxIndexCount: Integer; Const faceAttribute: Pinteger): Integer; cdecl; external newtondll;
Procedure NewtonStaticCollisionSetDebugCallback(Const staticCollision: PNewtonCollision; userCallback: NewtonTreeCollisionCallback); cdecl; external newtondll;
{ General purpose collision library functions }
Function NewtonCollisionCreateInstance(Const collision: PNewtonCollision): PNewtonCollision; cdecl; external newtondll;
Function NewtonCollisionGetType(Const collision: PNewtonCollision): Integer; cdecl; external newtondll;
Function NewtonCollisionIsConvexShape(Const collision: PNewtonCollision): Integer; cdecl; external newtondll;
Function NewtonCollisionIsStaticShape(Const collision: PNewtonCollision): Integer; cdecl; external newtondll;
Procedure NewtonCollisionSetUserData(Const collision: PNewtonCollision; Const userData: Pointer); cdecl; external newtondll;
Function NewtonCollisionGetUserData(Const collision: PNewtonCollision): Pointer; cdecl; external newtondll;
Procedure NewtonCollisionSetUserID(Const collision: PNewtonCollision; id: int64); cdecl; external newtondll;
Function NewtonCollisionGetUserID(Const collision: PNewtonCollision): int64; cdecl; external newtondll;
Procedure NewtonCollisionGetMaterial(Const collision: PNewtonCollision; Const userData: PNewtonCollisionMaterial); cdecl; external newtondll;
Procedure NewtonCollisionSetMaterial(Const collision: PNewtonCollision; Const userData: PNewtonCollisionMaterial); cdecl; external newtondll;
Function NewtonCollisionGetSubCollisionHandle(Const collision: PNewtonCollision): Pointer; cdecl; external newtondll;
Function NewtonCollisionGetParentInstance(Const collision: PNewtonCollision): PNewtonCollision; cdecl; external newtondll;
Procedure NewtonCollisionSetMatrix(Const collision: PNewtonCollision; Const matrix: pfloat); cdecl; external newtondll;
Procedure NewtonCollisionGetMatrix(Const collision: PNewtonCollision; Const matrix: pfloat); cdecl; external newtondll;
Procedure NewtonCollisionSetScale(Const collision: PNewtonCollision; scaleX: dfloat; scaleY: dfloat; scaleZ: dfloat); cdecl; external newtondll;
Procedure NewtonCollisionGetScale(Const collision: PNewtonCollision; Const scaleX: pfloat; Const scaleY: pfloat; Const scaleZ: pfloat); cdecl; external newtondll;
Procedure NewtonDestroyCollision(Const collision: PNewtonCollision); cdecl; external newtondll;
Function NewtonCollisionGetSkinThickness(Const collision: PNewtonCollision): dfloat; cdecl; external newtondll;
Procedure NewtonCollisionSetSkinThickness(Const collision: PNewtonCollision; thickness: dfloat); cdecl; external newtondll;
Function NewtonCollisionIntersectionTest(Const newtonWorld: PNewtonWorld; Const collisionA: PNewtonCollision; Const matrixA: pfloat; Const collisionB: PNewtonCollision; Const matrixB: pfloat; threadIndex: Integer): Integer; cdecl; external newtondll;
Function NewtonCollisionPointDistance(Const newtonWorld: PNewtonWorld; Const point: pfloat; Const collision: PNewtonCollision; Const matrix: pfloat; Const contact: pfloat; Const normal: pfloat; threadIndex: Integer): Integer; cdecl; external newtondll;
Function NewtonCollisionClosestPoint(Const newtonWorld: PNewtonWorld; Const collisionA: PNewtonCollision; Const matrixA: pfloat; Const collisionB: PNewtonCollision; Const matrixB: pfloat; Const contactA: pfloat; Const contactB: pfloat; Const normalAB: pfloat; threadIndex: Integer): Integer; cdecl; external newtondll;
Function NewtonCollisionCollide(Const newtonWorld: PNewtonWorld; maxSize: Integer; Const collisionA: PNewtonCollision; Const matrixA: pfloat; Const collisionB: PNewtonCollision; Const matrixB: pfloat; Const contacts: pfloat; Const normals: pfloat; Const penetration: pfloat; Const attributeA: Pint64; Const attributeB: Pint64; threadIndex: Integer): Integer; cdecl; external newtondll;
Function NewtonCollisionCollideContinue(Const newtonWorld: PNewtonWorld; maxSize: Integer; timestep: dfloat; Const collisionA: PNewtonCollision; Const matrixA: pfloat; Const velocA: pfloat; Const omegaA: pfloat; Const collisionB: PNewtonCollision; Const matrixB: pfloat; Const velocB: pfloat; Const omegaB: pfloat; Const timeOfImpact: pfloat; Const contacts: pfloat; Const normals: pfloat; Const penetration: pfloat; Const attributeA: Pint64; Const attributeB: Pint64; threadIndex: Integer): Integer; cdecl; external newtondll;
Procedure NewtonCollisionSupportVertex(Const collision: PNewtonCollision; Const dir: pfloat; Const vertex: pfloat); cdecl; external newtondll;
Function NewtonCollisionRayCast(Const collision: PNewtonCollision; Const p0: pfloat; Const p1: pfloat; Const normal: pfloat; Const attribute: Pint64): dfloat; cdecl; external newtondll;
Procedure NewtonCollisionCalculateAABB(Const collision: PNewtonCollision; Const matrix: pfloat; Const p0: pfloat; Const p1: pfloat); cdecl; external newtondll;
Procedure NewtonCollisionForEachPolygonDo(Const collision: PNewtonCollision; Const matrix: pfloat; callback: NewtonCollisionIterator; Const userData: Pointer); cdecl; external newtondll;
{ collision aggregates, are a collision node on eh broad phase the serve as the root nod for a collection of rigid bodies
   that shared the property of being in close proximity all the time, they are similar to compound collision by the group bodies instead of collision instances
   These are good for speeding calculation calculation of rag doll, Vehicles or contractions of rigid bodied lined by joints.
   also for example if you know that many the life time of a group of bodies like the object on a house of a building will be localize to the confide of the building
   then warping the bodies under an aggregate will reduce collision calculation of almost an order of magnitude. }
Function NewtonCollisionAggregateCreate(Const world: PNewtonWorld): Pointer; cdecl; external newtondll;
Procedure NewtonCollisionAggregateDestroy(Const aggregate: Pointer); cdecl; external newtondll;
Procedure NewtonCollisionAggregateAddBody(Const aggregate: Pointer; Const body: pNewtonBody); cdecl; external newtondll;
Procedure NewtonCollisionAggregateRemoveBody(Const aggregate: Pointer; Const body: pNewtonBody); cdecl; external newtondll;
Function NewtonCollisionAggregateGetSelfCollision(Const aggregate: Pointer): Integer; cdecl; external newtondll;
Procedure NewtonCollisionAggregateSetSelfCollision(Const aggregate: Pointer; state: Integer); cdecl; external newtondll;
{ transforms utility functions }
Procedure NewtonSetEulerAngle(Const eulersAngles: pfloat; Const matrix: pfloat); cdecl; external newtondll;
Procedure NewtonGetEulerAngle(Const matrix: pfloat; Const eulersAngles0: pfloat; Const eulersAngles1: pfloat); cdecl; external newtondll;
Function NewtonCalculateSpringDamperAcceleration(dt: dfloat; ks: dfloat; x: dfloat; kd: dfloat; s: dfloat): dfloat; cdecl; external newtondll;
{ body manipulation functions }
Function NewtonCreateDynamicBody(Const newtonWorld: PNewtonWorld; Const collision: PNewtonCollision; Const matrix: pfloat): pNewtonBody; cdecl; external newtondll;
Function NewtonCreateKinematicBody(Const newtonWorld: PNewtonWorld; Const collision: PNewtonCollision; Const matrix: pfloat): pNewtonBody; cdecl; external newtondll;
Function NewtonCreateAsymetricDynamicBody(Const newtonWorld: PNewtonWorld; Const collision: PNewtonCollision; Const matrix: pfloat): pNewtonBody; cdecl; external newtondll;
Procedure NewtonDestroyBody(Const body: pNewtonBody); cdecl; external newtondll;
Function NewtonBodyGetSimulationState(Const body: pNewtonBody): Integer; cdecl; external newtondll;
Procedure NewtonBodySetSimulationState(Const bodyPtr: pNewtonBody; Const state: Integer); cdecl; external newtondll;
Function NewtonBodyGetType(Const body: pNewtonBody): Integer; cdecl; external newtondll;
Function NewtonBodyGetCollidable(Const body: pNewtonBody): Integer; cdecl; external newtondll;
Procedure NewtonBodySetCollidable(Const body: pNewtonBody; collidableState: Integer); cdecl; external newtondll;
Procedure NewtonBodyAddForce(Const body: pNewtonBody; Const force: pfloat); cdecl; external newtondll;
Procedure NewtonBodyAddTorque(Const body: pNewtonBody; Const torque: pfloat); cdecl; external newtondll;
Procedure NewtonBodySetCentreOfMass(Const body: pNewtonBody; Const com: pfloat); cdecl; external newtondll;
Procedure NewtonBodySetMassMatrix(Const body: pNewtonBody; mass: dfloat; Ixx: dfloat; Iyy: dfloat; Izz: dfloat); cdecl; external newtondll;
Procedure NewtonBodySetFullMassMatrix(Const body: pNewtonBody; mass: dfloat; Const inertiaMatrix: pfloat); cdecl; external newtondll;
Procedure NewtonBodySetMassProperties(Const body: pNewtonBody; mass: dfloat; Const collision: PNewtonCollision); cdecl; external newtondll;
Procedure NewtonBodySetMatrix(Const body: pNewtonBody; Const matrix: pfloat); cdecl; external newtondll;
Procedure NewtonBodySetMatrixNoSleep(Const body: pNewtonBody; Const matrix: pfloat); cdecl; external newtondll;
Procedure NewtonBodySetMatrixRecursive(Const body: pNewtonBody; Const matrix: pfloat); cdecl; external newtondll;
Procedure NewtonBodySetMaterialGroupID(Const body: pNewtonBody; id: Integer); cdecl; external newtondll;
Procedure NewtonBodySetContinuousCollisionMode(Const body: pNewtonBody; state: LongWord); cdecl; external newtondll;
Procedure NewtonBodySetJointRecursiveCollision(Const body: pNewtonBody; state: LongWord); cdecl; external newtondll;
Procedure NewtonBodySetOmega(Const body: pNewtonBody; Const omega: pfloat); cdecl; external newtondll;
Procedure NewtonBodySetOmegaNoSleep(Const body: pNewtonBody; Const omega: pfloat); cdecl; external newtondll;
Procedure NewtonBodySetVelocity(Const body: pNewtonBody; Const velocity: pfloat); cdecl; external newtondll;
Procedure NewtonBodySetVelocityNoSleep(Const body: pNewtonBody; Const velocity: pfloat); cdecl; external newtondll;
Procedure NewtonBodySetForce(Const body: pNewtonBody; Const force: pfloat); cdecl; external newtondll;
Procedure NewtonBodySetTorque(Const body: pNewtonBody; Const torque: pfloat); cdecl; external newtondll;
Procedure NewtonBodySetLinearDamping(Const body: pNewtonBody; linearDamp: dfloat); cdecl; external newtondll;
Procedure NewtonBodySetAngularDamping(Const body: pNewtonBody; Const angularDamp: pfloat); cdecl; external newtondll;
Procedure NewtonBodySetCollision(Const body: pNewtonBody; Const collision: PNewtonCollision); cdecl; external newtondll;
Procedure NewtonBodySetCollisionScale(Const body: pNewtonBody; scaleX: dfloat; scaleY: dfloat; scaleZ: dfloat); cdecl; external newtondll;
Function NewtonBodyGetSleepState(Const body: pNewtonBody): Integer; cdecl; external newtondll;
Procedure NewtonBodySetSleepState(Const body: pNewtonBody; state: Integer); cdecl; external newtondll;
Function NewtonBodyGetAutoSleep(Const body: pNewtonBody): Integer; cdecl; external newtondll;
Procedure NewtonBodySetAutoSleep(Const body: pNewtonBody; state: Integer); cdecl; external newtondll;
Function NewtonBodyGetFreezeState(Const body: pNewtonBody): Integer; cdecl; external newtondll;
Procedure NewtonBodySetFreezeState(Const body: pNewtonBody; state: Integer); cdecl; external newtondll;
Function NewtonBodyGetGyroscopicTorque(Const body: pNewtonBody): Integer; cdecl; external newtondll;
Procedure NewtonBodySetGyroscopicTorque(Const body: pNewtonBody; state: Integer); cdecl; external newtondll;
Procedure NewtonBodySetDestructorCallback(Const body: pNewtonBody; callback: NewtonBodyDestructor); cdecl; external newtondll;
Function NewtonBodyGetDestructorCallback(Const body: pNewtonBody): PNewtonBodyDestructor; cdecl; external newtondll;
Procedure NewtonBodySetTransformCallback(Const body: pNewtonBody; callback: NewtonSetTransform); cdecl; external newtondll;
Function NewtonBodyGetTransformCallback(Const body: pNewtonBody): PNewtonSetTransform; cdecl; external newtondll;
Procedure NewtonBodySetForceAndTorqueCallback(Const body: pNewtonBody; callback: NewtonApplyForceAndTorque); cdecl; external newtondll;
Function NewtonBodyGetForceAndTorqueCallback(Const body: pNewtonBody): PNewtonApplyForceAndTorque; cdecl; external newtondll;
Function NewtonBodyGetID(Const body: pNewtonBody): Integer; cdecl; external newtondll;
Procedure NewtonBodySetUserData(Const body: pNewtonBody; Const userData: Pointer); cdecl; external newtondll;
Function NewtonBodyGetUserData(Const body: pNewtonBody): Pointer; cdecl; external newtondll;
Function NewtonBodyGetWorld(Const body: pNewtonBody): PNewtonWorld; cdecl; external newtondll;
Function NewtonBodyGetCollision(Const body: pNewtonBody): PNewtonCollision; cdecl; external newtondll;
Function NewtonBodyGetMaterialGroupID(Const body: pNewtonBody): Integer; cdecl; external newtondll;
Function NewtonBodyGetSerializedID(Const body: pNewtonBody): Integer; cdecl; external newtondll;
Function NewtonBodyGetContinuousCollisionMode(Const body: pNewtonBody): Integer; cdecl; external newtondll;
Function NewtonBodyGetJointRecursiveCollision(Const body: pNewtonBody): Integer; cdecl; external newtondll;
Procedure NewtonBodyGetPosition(Const body: pNewtonBody; Const pos: pfloat); cdecl; external newtondll;
Procedure NewtonBodyGetMatrix(Const body: pNewtonBody; Const matrix: pfloat); cdecl; external newtondll;
Procedure NewtonBodyGetRotation(Const body: pNewtonBody; Const rotation: pfloat); cdecl; external newtondll;
Procedure NewtonBodyGetMass(Const body: pNewtonBody; mass: pfloat; Const Ixx: pfloat; Const Iyy: pfloat; Const Izz: pfloat); cdecl; external newtondll;
Procedure NewtonBodyGetInvMass(Const body: pNewtonBody; Const invMass: pfloat; Const invIxx: pfloat; Const invIyy: pfloat; Const invIzz: pfloat); cdecl; external newtondll;
Procedure NewtonBodyGetInertiaMatrix(Const body: pNewtonBody; Const inertiaMatrix: pfloat); cdecl; external newtondll;
Procedure NewtonBodyGetInvInertiaMatrix(Const body: pNewtonBody; Const invInertiaMatrix: pfloat); cdecl; external newtondll;
Procedure NewtonBodyGetOmega(Const body: pNewtonBody; Const vector: pfloat); cdecl; external newtondll;
Procedure NewtonBodyGetVelocity(Const body: pNewtonBody; Const vector: pfloat); cdecl; external newtondll;
Procedure NewtonBodyGetAlpha(Const body: pNewtonBody; Const vector: pfloat); cdecl; external newtondll;
Procedure NewtonBodyGetAcceleration(Const body: pNewtonBody; Const vector: pfloat); cdecl; external newtondll;
Procedure NewtonBodyGetForce(Const body: pNewtonBody; Const vector: pfloat); cdecl; external newtondll;
Procedure NewtonBodyGetTorque(Const body: pNewtonBody; Const vector: pfloat); cdecl; external newtondll;
Procedure NewtonBodyGetCentreOfMass(Const body: pNewtonBody; Const com: pfloat); cdecl; external newtondll;
Procedure NewtonBodyGetPointVelocity(Const body: pNewtonBody; Const point: pfloat; Const velocOut: pfloat); cdecl; external newtondll;
Procedure NewtonBodyApplyImpulsePair(Const body: pNewtonBody; Const linearImpulse: pfloat; Const angularImpulse: pfloat; timestep: dfloat); cdecl; external newtondll;
Procedure NewtonBodyAddImpulse(Const body: pNewtonBody; Const pointDeltaVeloc: pfloat; Const pointPosit: pfloat; timestep: dfloat); cdecl; external newtondll;
Procedure NewtonBodyApplyImpulseArray(Const body: pNewtonBody; impuleCount: Integer; strideInByte: Integer; Const impulseArray: pfloat; Const pointArray: pfloat; timestep: dfloat); cdecl; external newtondll;
Procedure NewtonBodyIntegrateVelocity(Const body: pNewtonBody; timestep: dfloat); cdecl; external newtondll;
Function NewtonBodyGetLinearDamping(Const body: pNewtonBody): dfloat; cdecl; external newtondll;
Procedure NewtonBodyGetAngularDamping(Const body: pNewtonBody; Const vector: pfloat); cdecl; external newtondll;
Procedure NewtonBodyGetAABB(Const body: pNewtonBody; Const p0: pfloat; Const p1: pfloat); cdecl; external newtondll;
Function NewtonBodyGetFirstJoint(Const body: pNewtonBody): PNewtonJoint; cdecl; external newtondll;
Function NewtonBodyGetNextJoint(Const body: pNewtonBody; Const joint: PNewtonJoint): PNewtonJoint; cdecl; external newtondll;
Function NewtonBodyGetFirstContactJoint(Const body: pNewtonBody): PNewtonJoint; cdecl; external newtondll;
Function NewtonBodyGetNextContactJoint(Const body: pNewtonBody; Const contactJoint: PNewtonJoint): PNewtonJoint; cdecl; external newtondll;
Function NewtonBodyFindContact(Const body0: pNewtonBody; Const body1: pNewtonBody): PNewtonJoint; cdecl; external newtondll;
{ contact joints interface }
Function NewtonContactJointGetFirstContact(Const contactJoint: PNewtonJoint): Pointer; cdecl; external newtondll;
Function NewtonContactJointGetNextContact(Const contactJoint: PNewtonJoint; Const contact: Pointer): Pointer; cdecl; external newtondll;
Function NewtonContactJointGetContactCount(Const contactJoint: PNewtonJoint): Integer; cdecl; external newtondll;
Procedure NewtonContactJointRemoveContact(Const contactJoint: PNewtonJoint; Const contact: Pointer); cdecl; external newtondll;
Function NewtonContactJointGetClosestDistance(Const contactJoint: PNewtonJoint): dfloat; cdecl; external newtondll;
Procedure NewtonContactJointResetSelftJointCollision(Const contactJoint: PNewtonJoint); cdecl; external newtondll;
Procedure NewtonContactJointResetIntraJointCollision(Const contactJoint: PNewtonJoint); cdecl; external newtondll;
Function NewtonContactGetMaterial(Const contact: Pointer): PNewtonMaterial; cdecl; external newtondll;
Function NewtonContactGetCollision0(Const contact: Pointer): PNewtonCollision; cdecl; external newtondll;
Function NewtonContactGetCollision1(Const contact: Pointer): PNewtonCollision; cdecl; external newtondll;
Function NewtonContactGetCollisionID0(Const contact: Pointer): Pointer; cdecl; external newtondll;
Function NewtonContactGetCollisionID1(Const contact: Pointer): Pointer; cdecl; external newtondll;
{ Common joint functions }
Function NewtonJointGetUserData(Const joint: PNewtonJoint): Pointer; cdecl; external newtondll;
Procedure NewtonJointSetUserData(Const joint: PNewtonJoint; Const userData: Pointer); cdecl; external newtondll;
Function NewtonJointGetBody0(Const joint: PNewtonJoint): pNewtonBody; cdecl; external newtondll;
Function NewtonJointGetBody1(Const joint: PNewtonJoint): pNewtonBody; cdecl; external newtondll;
Procedure NewtonJointGetInfo(Const joint: PNewtonJoint; Const info: PNewtonJointRecord); cdecl; external newtondll;
Function NewtonJointGetCollisionState(Const joint: PNewtonJoint): Integer; cdecl; external newtondll;
Procedure NewtonJointSetCollisionState(Const joint: PNewtonJoint; state: Integer); cdecl; external newtondll;
Function NewtonJointGetStiffness(Const joint: PNewtonJoint): dfloat; cdecl; external newtondll;
Procedure NewtonJointSetStiffness(Const joint: PNewtonJoint; state: dfloat); cdecl; external newtondll;
Procedure NewtonDestroyJoint(Const newtonWorld: PNewtonWorld; Const joint: PNewtonJoint); cdecl; external newtondll;
Procedure NewtonJointSetDestructor(Const joint: PNewtonJoint; destructorparam: NewtonConstraintDestructor); cdecl; external newtondll;
Function NewtonJointIsActive(Const joint: PNewtonJoint): Integer; cdecl; external newtondll;
{ particle system interface (soft bodies, individual, pressure bodies and cloth) }
Function NewtonCreateMassSpringDamperSystem(Const newtonWorld: PNewtonWorld; shapeID: Integer; Const points: pfloat; pointCount: Integer; strideInBytes: Integer; Const pointMass: pfloat; Const links: Pinteger; linksCount: Integer; Const linksSpring: pfloat; Const linksDamper: pfloat): PNewtonCollision; cdecl; external newtondll;
Function NewtonCreateDeformableSolid(Const newtonWorld: PNewtonWorld; Const mesh: PNewtonMesh; shapeID: Integer): PNewtonCollision; cdecl; external newtondll;
Function NewtonDeformableMeshGetParticleCount(Const deformableMesh: PNewtonCollision): Integer; cdecl; external newtondll;
Function NewtonDeformableMeshGetParticleStrideInBytes(Const deformableMesh: PNewtonCollision): Integer; cdecl; external newtondll;
Function NewtonDeformableMeshGetParticleArray(Const deformableMesh: PNewtonCollision): pfloat; cdecl; external newtondll;
{ Ball and Socket joint functions }
Function NewtonConstraintCreateBall(Const newtonWorld: PNewtonWorld; Const pivotPoint: pfloat; Const childBody: pNewtonBody; Const parentBody: pNewtonBody): PNewtonJoint; cdecl; external newtondll;
Procedure NewtonBallSetUserCallback(Const ball: PNewtonJoint; callback: NewtonBallCallback); cdecl; external newtondll;
Procedure NewtonBallGetJointAngle(Const ball: PNewtonJoint; angle: pfloat); cdecl; external newtondll;
Procedure NewtonBallGetJointOmega(Const ball: PNewtonJoint; omega: pfloat); cdecl; external newtondll;
Procedure NewtonBallGetJointForce(Const ball: PNewtonJoint; Const force: pfloat); cdecl; external newtondll;
Procedure NewtonBallSetConeLimits(Const ball: PNewtonJoint; Const pin: pfloat; maxConeAngle: dfloat; maxTwistAngle: dfloat); cdecl; external newtondll;
{ Hinge joint functions }
Function NewtonConstraintCreateHinge(Const newtonWorld: PNewtonWorld; Const pivotPoint: pfloat; Const pinDir: pfloat; Const childBody: pNewtonBody; Const parentBody: pNewtonBody): PNewtonJoint; cdecl; external newtondll;
Procedure NewtonHingeSetUserCallback(Const hinge: PNewtonJoint; callback: NewtonHingeCallback); cdecl; external newtondll;
Function NewtonHingeGetJointAngle(Const hinge: PNewtonJoint): dfloat; cdecl; external newtondll;
Function NewtonHingeGetJointOmega(Const hinge: PNewtonJoint): dfloat; cdecl; external newtondll;
Procedure NewtonHingeGetJointForce(Const hinge: PNewtonJoint; Const force: pfloat); cdecl; external newtondll;
Function NewtonHingeCalculateStopAlpha(Const hinge: PNewtonJoint; Const desc: PNewtonHingeSliderUpdateDesc; angle: dfloat): dfloat; cdecl; external newtondll;
{ Slider joint functions }
Function NewtonConstraintCreateSlider(Const newtonWorld: PNewtonWorld; Const pivotPoint: pfloat; Const pinDir: pfloat; Const childBody: pNewtonBody; Const parentBody: pNewtonBody): PNewtonJoint; cdecl; external newtondll;
Procedure NewtonSliderSetUserCallback(Const slider: PNewtonJoint; callback: NewtonSliderCallback); cdecl; external newtondll;
Function NewtonSliderGetJointPosit(Const slider: PNewtonJoint): dfloat; cdecl; external newtondll;
Function NewtonSliderGetJointVeloc(Const slider: PNewtonJoint): dfloat; cdecl; external newtondll;
Procedure NewtonSliderGetJointForce(Const slider: PNewtonJoint; Const force: pfloat); cdecl; external newtondll;
Function NewtonSliderCalculateStopAccel(Const slider: PNewtonJoint; Const desc: PNewtonHingeSliderUpdateDesc; position: dfloat): dfloat; cdecl; external newtondll;
{ Corkscrew joint functions }
Function NewtonConstraintCreateCorkscrew(Const newtonWorld: PNewtonWorld; Const pivotPoint: pfloat; Const pinDir: pfloat; Const childBody: pNewtonBody; Const parentBody: pNewtonBody): PNewtonJoint; cdecl; external newtondll;
Procedure NewtonCorkscrewSetUserCallback(Const corkscrew: PNewtonJoint; callback: NewtonCorkscrewCallback); cdecl; external newtondll;
Function NewtonCorkscrewGetJointPosit(Const corkscrew: PNewtonJoint): dfloat; cdecl; external newtondll;
Function NewtonCorkscrewGetJointAngle(Const corkscrew: PNewtonJoint): dfloat; cdecl; external newtondll;
Function NewtonCorkscrewGetJointVeloc(Const corkscrew: PNewtonJoint): dfloat; cdecl; external newtondll;
Function NewtonCorkscrewGetJointOmega(Const corkscrew: PNewtonJoint): dfloat; cdecl; external newtondll;
Procedure NewtonCorkscrewGetJointForce(Const corkscrew: PNewtonJoint; Const force: pfloat); cdecl; external newtondll;
Function NewtonCorkscrewCalculateStopAlpha(Const corkscrew: PNewtonJoint; Const desc: PNewtonHingeSliderUpdateDesc; angle: dfloat): dfloat; cdecl; external newtondll;
Function NewtonCorkscrewCalculateStopAccel(Const corkscrew: PNewtonJoint; Const desc: PNewtonHingeSliderUpdateDesc; position: dfloat): dfloat; cdecl; external newtondll;
{ Universal joint functions }
Function NewtonConstraintCreateUniversal(Const newtonWorld: PNewtonWorld; Const pivotPoint: pfloat; Const pinDir0: pfloat; Const pinDir1: pfloat; Const childBody: pNewtonBody; Const parentBody: pNewtonBody): PNewtonJoint; cdecl; external newtondll;
Procedure NewtonUniversalSetUserCallback(Const universal: PNewtonJoint; callback: NewtonUniversalCallback); cdecl; external newtondll;
Function NewtonUniversalGetJointAngle0(Const universal: PNewtonJoint): dfloat; cdecl; external newtondll;
Function NewtonUniversalGetJointAngle1(Const universal: PNewtonJoint): dfloat; cdecl; external newtondll;
Function NewtonUniversalGetJointOmega0(Const universal: PNewtonJoint): dfloat; cdecl; external newtondll;
Function NewtonUniversalGetJointOmega1(Const universal: PNewtonJoint): dfloat; cdecl; external newtondll;
Procedure NewtonUniversalGetJointForce(Const universal: PNewtonJoint; Const force: pfloat); cdecl; external newtondll;
Function NewtonUniversalCalculateStopAlpha0(Const universal: PNewtonJoint; Const desc: PNewtonHingeSliderUpdateDesc; angle: dfloat): dfloat; cdecl; external newtondll;
Function NewtonUniversalCalculateStopAlpha1(Const universal: PNewtonJoint; Const desc: PNewtonHingeSliderUpdateDesc; angle: dfloat): dfloat; cdecl; external newtondll;
{ Up vector joint functions }
Function NewtonConstraintCreateUpVector(Const newtonWorld: PNewtonWorld; Const pinDir: pfloat; Const body: pNewtonBody): PNewtonJoint; cdecl; external newtondll;
Procedure NewtonUpVectorGetPin(Const upVector: PNewtonJoint; pin: dfloat); cdecl; external newtondll;
Procedure NewtonUpVectorSetPin(Const upVector: PNewtonJoint; Const pin: dfloat); cdecl; external newtondll;
{ User defined bilateral Joint }
Function NewtonConstraintCreateUserJoint(Const newtonWorld: PNewtonWorld; maxDOF: Integer; callback: NewtonUserBilateralCallback; Const childBody: pNewtonBody; Const parentBody: pNewtonBody): PNewtonJoint; cdecl; external newtondll;
Function NewtonUserJointGetSolverModel(Const joint: PNewtonJoint): Integer; cdecl; external newtondll;
Procedure NewtonUserJointSetSolverModel(Const joint: PNewtonJoint; model: Integer); cdecl; external newtondll;
Procedure NewtonUserJointMassScale(Const joint: PNewtonJoint; scaleBody0: dfloat; scaleBody1: dfloat); cdecl; external newtondll;
Procedure NewtonUserJointSetFeedbackCollectorCallback(Const joint: PNewtonJoint; getFeedback: NewtonUserBilateralCallback); cdecl; external newtondll;
Procedure NewtonUserJointAddLinearRow(Const joint: PNewtonJoint; Const pivot0: pfloat; Const pivot1: pfloat; Const dir: pfloat); cdecl; external newtondll;
Procedure NewtonUserJointAddAngularRow(Const joint: PNewtonJoint; relativeAngle: dfloat; Const dir: pfloat); cdecl; external newtondll;
Procedure NewtonUserJointAddGeneralRow(Const joint: PNewtonJoint; Const jacobian0: pfloat; Const jacobian1: pfloat); cdecl; external newtondll;
Procedure NewtonUserJointSetRowMinimumFriction(Const joint: PNewtonJoint; friction: dfloat); cdecl; external newtondll;
Procedure NewtonUserJointSetRowMaximumFriction(Const joint: PNewtonJoint; friction: dfloat); cdecl; external newtondll;
Function NewtonUserJointCalculateRowZeroAcceleration(Const joint: PNewtonJoint): dfloat; cdecl; external newtondll;
Function NewtonUserJointGetRowAcceleration(Const joint: PNewtonJoint): dfloat; cdecl; external newtondll;
Procedure NewtonUserJointGetRowJacobian(Const joint: PNewtonJoint; Const linear0: pfloat; Const angula0: pfloat; Const linear1: pfloat; Const angula1: pfloat); cdecl; external newtondll;
Procedure NewtonUserJointSetRowAcceleration(Const joint: PNewtonJoint; acceleration: dfloat); cdecl; external newtondll;
Procedure NewtonUserJointSetRowSpringDamperAcceleration(Const joint: PNewtonJoint; rowStiffness: dfloat; spring: dfloat; damper: dfloat); cdecl; external newtondll;
Procedure NewtonUserJointSetRowStiffness(Const joint: PNewtonJoint; stiffness: dfloat); cdecl; external newtondll;
Function NewtonUserJoinRowsCount(Const joint: PNewtonJoint): Integer; cdecl; external newtondll;
Procedure NewtonUserJointGetGeneralRow(Const joint: PNewtonJoint; index: Integer; Const jacobian0: pfloat; Const jacobian1: pfloat); cdecl; external newtondll;
Function NewtonUserJointGetRowForce(Const joint: PNewtonJoint; row: Integer): dfloat; cdecl; external newtondll;
{ Mesh joint functions }
Function NewtonMeshCreate(Const newtonWorld: PNewtonWorld): PNewtonMesh; cdecl; external newtondll;
Function NewtonMeshCreateFromMesh(Const mesh: PNewtonMesh): PNewtonMesh; cdecl; external newtondll;
Function NewtonMeshCreateFromCollision(Const collision: PNewtonCollision): PNewtonMesh; cdecl; external newtondll;
Function NewtonMeshCreateTetrahedraIsoSurface(Const mesh: PNewtonMesh): PNewtonMesh; cdecl; external newtondll;
Function NewtonMeshCreateConvexHull(Const newtonWorld: PNewtonWorld; pointCount: Integer; Const vertexCloud: pfloat; strideInBytes: Integer; tolerance: dfloat): PNewtonMesh; cdecl; external newtondll;
Function NewtonMeshCreateVoronoiConvexDecomposition(Const newtonWorld: PNewtonWorld; pointCount: Integer; Const vertexCloud: pfloat; strideInBytes: Integer; materialID: Integer; Const textureMatrix: pfloat): PNewtonMesh; cdecl; external newtondll;
Function NewtonMeshCreateFromSerialization(Const newtonWorld: PNewtonWorld; deserializeFunction: NewtonDeserializeCallback; Const serializeHandle: Pointer): PNewtonMesh; cdecl; external newtondll;
Procedure NewtonMeshDestroy(Const mesh: PNewtonMesh); cdecl; external newtondll;
Procedure NewtonMeshSerialize(Const mesh: PNewtonMesh; serializeFunction: NewtonSerializeCallback; Const serializeHandle: Pointer); cdecl; external newtondll;
Procedure NewtonMeshSaveOFF(Const mesh: PNewtonMesh; Const filename: pchar); cdecl; external newtondll;
Function NewtonMeshLoadOFF(Const newtonWorld: PNewtonWorld; Const filename: pchar): PNewtonMesh; cdecl; external newtondll;
Function NewtonMeshLoadTetrahedraMesh(Const newtonWorld: PNewtonWorld; Const filename: pchar): PNewtonMesh; cdecl; external newtondll;
Procedure NewtonMeshFlipWinding(Const mesh: PNewtonMesh); cdecl; external newtondll;
Procedure NewtonMeshApplyTransform(Const mesh: PNewtonMesh; Const matrix: pfloat); cdecl; external newtondll;
Procedure NewtonMeshCalculateOOBB(Const mesh: PNewtonMesh; Const matrix: pfloat; Const x: pfloat; Const y: pfloat; Const z: pfloat); cdecl; external newtondll;
Procedure NewtonMeshCalculateVertexNormals(Const mesh: PNewtonMesh; angleInRadians: dfloat); cdecl; external newtondll;
Procedure NewtonMeshApplySphericalMapping(Const mesh: PNewtonMesh; material: Integer; Const aligmentMatrix: pfloat); cdecl; external newtondll;
Procedure NewtonMeshApplyCylindricalMapping(Const mesh: PNewtonMesh; cylinderMaterial: Integer; capMaterial: Integer; Const aligmentMatrix: pfloat); cdecl; external newtondll;
Procedure NewtonMeshApplyBoxMapping(Const mesh: PNewtonMesh; frontMaterial: Integer; sideMaterial: Integer; topMaterial: Integer; Const aligmentMatrix: pfloat); cdecl; external newtondll;
Procedure NewtonMeshApplyAngleBasedMapping(Const mesh: PNewtonMesh; material: Integer; reportPrograssCallback: NewtonReportProgress; Const reportPrgressUserData: Pointer; Const aligmentMatrix: pfloat); cdecl; external newtondll;
Procedure NewtonCreateTetrahedraLinearBlendSkinWeightsChannel(Const tetrahedraMesh: PNewtonMesh; Const skinMesh: PNewtonMesh); cdecl; external newtondll;
Procedure NewtonMeshOptimize(Const mesh: PNewtonMesh); cdecl; external newtondll;
Procedure NewtonMeshOptimizePoints(Const mesh: PNewtonMesh); cdecl; external newtondll;
Procedure NewtonMeshOptimizeVertex(Const mesh: PNewtonMesh); cdecl; external newtondll;
Function NewtonMeshIsOpenMesh(Const mesh: PNewtonMesh): Integer; cdecl; external newtondll;
Procedure NewtonMeshFixTJoints(Const mesh: PNewtonMesh); cdecl; external newtondll;
Procedure NewtonMeshPolygonize(Const mesh: PNewtonMesh); cdecl; external newtondll;
Procedure NewtonMeshTriangulate(Const mesh: PNewtonMesh); cdecl; external newtondll;
Function NewtonMeshUnion(Const mesh: PNewtonMesh; Const clipper: PNewtonMesh; Const clipperMatrix: pfloat): PNewtonMesh; cdecl; external newtondll;
Function NewtonMeshDifference(Const mesh: PNewtonMesh; Const clipper: PNewtonMesh; Const clipperMatrix: pfloat): PNewtonMesh; cdecl; external newtondll;
Function NewtonMeshIntersection(Const mesh: PNewtonMesh; Const clipper: PNewtonMesh; Const clipperMatrix: pfloat): PNewtonMesh; cdecl; external newtondll;
Procedure NewtonMeshClip(Const mesh: PNewtonMesh; Const clipper: PNewtonMesh; Const clipperMatrix: pfloat; Const topMesh: PNewtonMesh; Const bottomMesh: PNewtonMesh); cdecl; external newtondll;
Function NewtonMeshConvexMeshIntersection(Const mesh: PNewtonMesh; Const convexMesh: PNewtonMesh): PNewtonMesh; cdecl; external newtondll;
Function NewtonMeshSimplify(Const mesh: PNewtonMesh; maxVertexCount: Integer; reportPrograssCallback: NewtonReportProgress; Const reportPrgressUserData: Pointer): PNewtonMesh; cdecl; external newtondll;
Function NewtonMeshApproximateConvexDecomposition(Const mesh: PNewtonMesh; maxConcavity: dfloat; backFaceDistanceFactor: dfloat; maxCount: Integer; maxVertexPerHull: Integer; reportProgressCallback: NewtonReportProgress; Const reportProgressUserData: Pointer): PNewtonMesh; cdecl; external newtondll;
Procedure NewtonRemoveUnusedVertices(Const mesh: PNewtonMesh; Const vertexRemapTable: Pinteger); cdecl; external newtondll;
Procedure NewtonMeshBeginBuild(Const mesh: PNewtonMesh); cdecl; external newtondll;
Procedure NewtonMeshBeginFace(Const mesh: PNewtonMesh); cdecl; external newtondll;
Procedure NewtonMeshAddPoint(Const mesh: PNewtonMesh; x: double; y: double; z: double); cdecl; external newtondll;
Procedure NewtonMeshAddLayer(Const mesh: PNewtonMesh; layerIndex: Integer); cdecl; external newtondll;
Procedure NewtonMeshAddMaterial(Const mesh: PNewtonMesh; materialIndex: Integer); cdecl; external newtondll;
Procedure NewtonMeshAddNormal(Const mesh: PNewtonMesh; x: dfloat; y: dfloat; z: dfloat); cdecl; external newtondll;
Procedure NewtonMeshAddBinormal(Const mesh: PNewtonMesh; x: dfloat; y: dfloat; z: dfloat); cdecl; external newtondll;
Procedure NewtonMeshAddUV0(Const mesh: PNewtonMesh; u: dfloat; v: dfloat); cdecl; external newtondll;
Procedure NewtonMeshAddUV1(Const mesh: PNewtonMesh; u: dfloat; v: dfloat); cdecl; external newtondll;
Procedure NewtonMeshAddVertexColor(Const mesh: PNewtonMesh; r: Single; g: Single; b: Single; a: Single); cdecl; external newtondll;
Procedure NewtonMeshEndFace(Const mesh: PNewtonMesh); cdecl; external newtondll;
Procedure NewtonMeshEndBuild(Const mesh: PNewtonMesh); cdecl; external newtondll;
Procedure NewtonMeshClearVertexFormat(Const format: PNewtonMeshVertexFormat); cdecl; external newtondll;
Procedure NewtonMeshBuildFromVertexListIndexList(Const mesh: PNewtonMesh; Const format: PNewtonMeshVertexFormat); cdecl; external newtondll;
Function NewtonMeshGetPointCount(Const mesh: PNewtonMesh): Integer; cdecl; external newtondll;
Function NewtonMeshGetIndexToVertexMap(Const mesh: PNewtonMesh): Pinteger; cdecl; external newtondll;
Procedure NewtonMeshGetVertexDoubleChannel(Const mesh: PNewtonMesh; vertexStrideInByte: Integer; Const outBuffer: Pdouble); cdecl; external newtondll;
Procedure NewtonMeshGetVertexChannel(Const mesh: PNewtonMesh; vertexStrideInByte: Integer; Const outBuffer: pfloat); cdecl; external newtondll;
Procedure NewtonMeshGetNormalChannel(Const mesh: PNewtonMesh; vertexStrideInByte: Integer; Const outBuffer: pfloat); cdecl; external newtondll;
Procedure NewtonMeshGetBinormalChannel(Const mesh: PNewtonMesh; vertexStrideInByte: Integer; Const outBuffer: pfloat); cdecl; external newtondll;
Procedure NewtonMeshGetUV0Channel(Const mesh: PNewtonMesh; vertexStrideInByte: Integer; Const outBuffer: pfloat); cdecl; external newtondll;
Procedure NewtonMeshGetUV1Channel(Const mesh: PNewtonMesh; vertexStrideInByte: Integer; Const outBuffer: pfloat); cdecl; external newtondll;
Procedure NewtonMeshGetVertexColorChannel(Const mesh: PNewtonMesh; vertexStrideInByte: Integer; Const outBuffer: pfloat); cdecl; external newtondll;
Function NewtonMeshHasNormalChannel(Const mesh: PNewtonMesh): Integer; cdecl; external newtondll;
Function NewtonMeshHasBinormalChannel(Const mesh: PNewtonMesh): Integer; cdecl; external newtondll;
Function NewtonMeshHasUV0Channel(Const mesh: PNewtonMesh): Integer; cdecl; external newtondll;
Function NewtonMeshHasUV1Channel(Const mesh: PNewtonMesh): Integer; cdecl; external newtondll;
Function NewtonMeshHasVertexColorChannel(Const mesh: PNewtonMesh): Integer; cdecl; external newtondll;
Function NewtonMeshBeginHandle(Const mesh: PNewtonMesh): Pointer; cdecl; external newtondll;
Procedure NewtonMeshEndHandle(Const mesh: PNewtonMesh; Const handle: Pointer); cdecl; external newtondll;
Function NewtonMeshFirstMaterial(Const mesh: PNewtonMesh; Const handle: Pointer): Integer; cdecl; external newtondll;
Function NewtonMeshNextMaterial(Const mesh: PNewtonMesh; Const handle: Pointer; materialId: Integer): Integer; cdecl; external newtondll;
Function NewtonMeshMaterialGetMaterial(Const mesh: PNewtonMesh; Const handle: Pointer; materialId: Integer): Integer; cdecl; external newtondll;
Function NewtonMeshMaterialGetIndexCount(Const mesh: PNewtonMesh; Const handle: Pointer; materialId: Integer): Integer; cdecl; external newtondll;
Procedure NewtonMeshMaterialGetIndexStream(Const mesh: PNewtonMesh; Const handle: Pointer; materialId: Integer; Const index: Pinteger); cdecl; external newtondll;
Procedure NewtonMeshMaterialGetIndexStreamShort(Const mesh: PNewtonMesh; Const handle: Pointer; materialId: Integer; Const index: SmallInt); cdecl; external newtondll;
Function NewtonMeshCreateFirstSingleSegment(Const mesh: PNewtonMesh): PNewtonMesh; cdecl; external newtondll;
Function NewtonMeshCreateNextSingleSegment(Const mesh: PNewtonMesh; Const segment: PNewtonMesh): PNewtonMesh; cdecl; external newtondll;
Function NewtonMeshCreateFirstLayer(Const mesh: PNewtonMesh): PNewtonMesh; cdecl; external newtondll;
Function NewtonMeshCreateNextLayer(Const mesh: PNewtonMesh; Const segment: PNewtonMesh): PNewtonMesh; cdecl; external newtondll;
Function NewtonMeshGetTotalFaceCount(Const mesh: PNewtonMesh): Integer; cdecl; external newtondll;
Function NewtonMeshGetTotalIndexCount(Const mesh: PNewtonMesh): Integer; cdecl; external newtondll;
Procedure NewtonMeshGetFaces(Const mesh: PNewtonMesh; Const faceIndexCount: Pinteger; Const faceMaterial: Pinteger; Const faceIndices: PPointer); cdecl; external newtondll;
Function NewtonMeshGetVertexCount(Const mesh: PNewtonMesh): Integer; cdecl; external newtondll;
Function NewtonMeshGetVertexStrideInByte(Const mesh: PNewtonMesh): Integer; cdecl; external newtondll;
Function NewtonMeshGetVertexArray(Const mesh: PNewtonMesh): Pdouble; cdecl; external newtondll;
Function NewtonMeshGetVertexBaseCount(Const mesh: PNewtonMesh): Integer; cdecl; external newtondll;
Procedure NewtonMeshSetVertexBaseCount(Const mesh: PNewtonMesh; baseCount: Integer); cdecl; external newtondll;
Function NewtonMeshGetFirstVertex(Const mesh: PNewtonMesh): Pointer; cdecl; external newtondll;
Function NewtonMeshGetNextVertex(Const mesh: PNewtonMesh; Const vertex: Pointer): Pointer; cdecl; external newtondll;
Function NewtonMeshGetVertexIndex(Const mesh: PNewtonMesh; Const vertex: Pointer): Integer; cdecl; external newtondll;
Function NewtonMeshGetFirstPoint(Const mesh: PNewtonMesh): Pointer; cdecl; external newtondll;
Function NewtonMeshGetNextPoint(Const mesh: PNewtonMesh; Const point: Pointer): Pointer; cdecl; external newtondll;
Function NewtonMeshGetPointIndex(Const mesh: PNewtonMesh; Const point: Pointer): Integer; cdecl; external newtondll;
Function NewtonMeshGetVertexIndexFromPoint(Const mesh: PNewtonMesh; Const point: Pointer): Integer; cdecl; external newtondll;
Function NewtonMeshGetFirstEdge(Const mesh: PNewtonMesh): Pointer; cdecl; external newtondll;
Function NewtonMeshGetNextEdge(Const mesh: PNewtonMesh; Const edge: Pointer): Pointer; cdecl; external newtondll;
Procedure NewtonMeshGetEdgeIndices(Const mesh: PNewtonMesh; Const edge: Pointer; Const v0: Pinteger; Const v1: Pinteger); cdecl; external newtondll;
Function NewtonMeshGetFirstFace(Const mesh: PNewtonMesh): Pointer; cdecl; external newtondll;
Function NewtonMeshGetNextFace(Const mesh: PNewtonMesh; Const face: Pointer): Pointer; cdecl; external newtondll;
Function NewtonMeshIsFaceOpen(Const mesh: PNewtonMesh; Const face: Pointer): Integer; cdecl; external newtondll;
Function NewtonMeshGetFaceMaterial(Const mesh: PNewtonMesh; Const face: Pointer): Integer; cdecl; external newtondll;
Function NewtonMeshGetFaceIndexCount(Const mesh: PNewtonMesh; Const face: Pointer): Integer; cdecl; external newtondll;
Procedure NewtonMeshGetFaceIndices(Const mesh: PNewtonMesh; Const face: Pointer; Const indices: Pinteger); cdecl; external newtondll;
Procedure NewtonMeshGetFacePointIndices(Const mesh: PNewtonMesh; Const face: Pointer; Const indices: Pinteger); cdecl; external newtondll;
Procedure NewtonMeshCalculateFaceNormal(Const mesh: PNewtonMesh; Const face: Pointer; Const normal: Pdouble); cdecl; external newtondll;
Procedure NewtonMeshSetFaceMaterial(Const mesh: PNewtonMesh; Const face: Pointer; matId: Integer); cdecl; external newtondll;

Implementation

End.

